CREATE OR REPLACE VIEW "ta_descriptions" AS 
SELECT *
FROM
  (
 VALUES 
  ROW ('Qch7DwouX1', 'en', 'Low Utilization Amazon EC2 Instances', 'Checks the Amazon Elastic Compute Cloud (Amazon EC2) instances that were running at any time during the last 14 days and alerts you if the daily CPU utilization was 10% or less and network I/O was 5 MB or less on 4 or more days. Running instances generate hourly usage charges. Although some scenarios can result in low utilization by design, you can often lower your costs by managing the number and size of your instances.')
, ROW ('hjLMh88uM8', 'en', 'Idle Load Balancers', 'Checks your Elastic Load Balancing configuration for load balancers that are not actively used. Any load balancer that is configured accrues charges. If a load balancer has no associated back-end instances or if network traffic is severely limited, the load balancer is not being used effectively.')
, ROW ('DAvU99Dc4C', 'en', 'Underutilized Amazon EBS Volumes', 'Checks Amazon Elastic Block Store (Amazon EBS) volume configurations and warns when volumes appear to be underused. Charges begin when a volume is created. If a volume remains unattached or has very low write activity (excluding boot volumes) for a period of time, the volume is probably not being used.')
, ROW ('Z4AUBRNSmz', 'en', 'Unassociated Elastic IP Addresses', 'Checks for Elastic IP addresses (EIPs) that are not associated with a running Amazon Elastic Compute Cloud (Amazon EC2) instance. EIPs are static IP addresses designed for dynamic cloud computing. Unlike traditional static IP addresses, EIPs can mask the failure of an instance or Availability Zone by remapping a public IP address to another instance in your account. A nominal charge is imposed for an EIP that is not associated with a running instance.')
, ROW ('HCP4007jGY', 'en', 'Security Groups - Specific Ports Unrestricted', 'Checks security groups for rules that allow unrestricted access (0.0.0.0/0) to specific ports. Unrestricted access increases opportunities for malicious activity (hacking, denial-of-service attacks, loss of data). The ports with highest risk are flagged red, and those with less risk are flagged yellow. Ports flagged green are typically used by applications that require unrestricted access, such as HTTP and SMTP.')
, ROW ('1iG5NDGVre', 'en', 'Security Groups - Unrestricted Access', 'Checks security groups for rules that allow unrestricted access to a resource. Unrestricted access increases opportunities for malicious activity (hacking, denial-of-service attacks, loss of data).')
, ROW ('zXCkfM1nI3', 'en', 'IAM Use', 'This check is intended to discourage the use of root access by checking for existence of at least one IAM user. You may ignore the alert if you are following the best practice of centralizing identities and configuring users in an <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers.html" target="_blank">external identity provider</a> or <a href="https://aws.amazon.com/single-sign-on/" target="_blank">AWS Single Sign-On</a>. ')
, ROW ('Pfx0RwqBli', 'en', 'Amazon S3 Bucket Permissions', 'Checks buckets in Amazon Simple Storage Service (Amazon S3) that have open access permissions or allow access to any authenticated AWS user. Bucket permissions that grant List access can result in higher than expected charges if objects in the bucket are listed by unintended users at a high frequency. Bucket permissions that grant Upload/Delete access create potential security vulnerabilities by allowing users that to add, modify, or remove items in a bucket.')
, ROW ('7DAFEmoDos', 'en', 'MFA on Root Account', 'Checks the root account and warns if multi-factor authentication (MFA) is not enabled. For increased security, we recommend that you protect your account by using MFA, which requires a user to enter a unique authentication code from their MFA hardware or virtual device when interacting with the AWS console and associated websites.')
, ROW ('Yw2K9puPzl', 'en', 'IAM Password Policy', 'Checks the password policy for your account and warns when a password policy is not enabled, or if password content requirements have not been enabled. Password content requirements increase the overall security of your AWS environment by enforcing the creation of strong user passwords. When you create or change a password policy, the change is enforced immediately for new users but does not require existing users to change their passwords. ')
, ROW ('nNauJisYIT', 'en', 'Amazon RDS Security Group Access Risk', 'Checks security group configurations for Amazon Relational Database Service (Amazon RDS) and warns when a security group rule might grant overly permissive access to your database. Recommended configuration for any security group rule is to allow access from specific Amazon Elastic Compute Cloud (Amazon EC2) security groups or from a specific IP address. Data for Amazon Relational Database Service (Amazon RDS) instances created in the Asia Pacific (Seoul) region (sa-east-1) is not available. We are working to fix this issue as soon as possible.')
, ROW ('H7IgTzjTYb', 'en', 'Amazon EBS Snapshots', 'Checks the age of the snapshots for your Amazon Elastic Block Store (Amazon EBS) volumes (available or in-use). Even though Amazon EBS volumes are replicated, failures can occur. Snapshots are persisted to Amazon Simple Storage Service (Amazon S3) for durable storage and point-in-time recovery.')
, ROW ('wuy7G1zxql', 'en', 'Amazon EC2 Availability Zone Balance', 'Checks the distribution of Amazon Elastic Compute Cloud (Amazon EC2) instances across Availability Zones in a region. Availability Zones are distinct locations that are designed to be insulated from failures in other Availability Zones and to provide inexpensive, low-latency network connectivity to other Availability Zones in the same region. By launching instances in multiple Availability Zones in the same region, you can help protect your applications from a single point of failure.')
, ROW ('iqdCTZKCUp', 'en', 'Load Balancer Optimization', 'Checks your load balancer configuration. To help increase the level of fault tolerance in Amazon Elastic Compute Cloud (EC2) when using Elastic Load Balancing, we recommend running an equal number of instances across multiple Availability Zones in a region. A load balancer that is configured accrues charges, so this is a cost-optimization check as well.<br/><br/><b>Alert Criteria</b><br/>Yellow: A load balancer is enabled for a single Availability Zone.<br/>Yellow: A load balancer is enabled for an Availability Zone that has no active instances.<br/>Yellow: The Amazon EC2 instances that are registered with a load balancer are unevenly distributed across Availability Zones. (The difference between the highest and lowest instance counts in utilized Availability Zones is more than 1, and the difference is more than 20% of the highest count.)<br/><br/><b>Recommended Action</b><br/>Ensure that your load balancer points to active and healthy instances in at least two Availability Zones. For more information, see <a href="http://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/enable-disable-az.html#US_AddLBAvailabilityZone" target="_blank">Add Availability Zone</a>.<br/>If your load balancer is configured for an Availability Zone with no healthy instances, or if there is an imbalance of instances across the Availability Zones, determine if all the Availability Zones are necessary. Omit any unnecessary Availability Zones and ensure there is a balanced distribution of instances across the remaining Availability Zones. For more information, see <a href="http://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/enable-disable-az.html#US_ShrinkLBApp04" target="_blank">Remove Availability Zone</a>.<br/><br/><b>Additional Resources</b><br/><a href="http://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/TerminologyandKeyConcepts.html#AZ-Region" target="_blank">Availability Zones and Regions</a><br/><a href="http://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/UserScenarios.html" target="_blank">Managing Load Balancers</a><br/><a href="http://aws.amazon.com/articles/1636185810492479" target="_blank">Best Practices in Evaluating Elastic Load Balancing</a>')
, ROW ('S45wrEXrLz', 'en', 'VPN Tunnel Redundancy', 'Checks the number of tunnels that are active for each of your VPNs. A VPN should have two tunnels configured at all times to provide redundancy in case of outage or planned maintenance of the devices at the AWS endpoint. For some hardware, only one tunnel is active at a time (see the <a href="http://docs.aws.amazon.com/AmazonVPC/latest/NetworkAdminGuide/Welcome.html" target="_blank">Amazon Virtual Private Cloud Network Administrator Guide</a>). If a VPN has no active tunnels, charges for the VPN might still apply.')
, ROW ('ZRxQlPsb6c', 'en', 'High Utilization Amazon EC2 Instances', 'Checks the Amazon Elastic Compute Cloud (Amazon EC2) instances that were running at any time during the last 14 days and alerts you if the daily CPU utilization was more than 90% on 4 or more days. Consistent high utilization can indicate optimized, steady performance, but it can also indicate that an application does not have enough resources. To get daily CPU utilization data, download the report for this check.')
, ROW ('8CNsSllI5v', 'en', 'Auto Scaling Group Resources', 'Checks the availability of resources associated with launch configurations and your Auto Scaling groups. Auto Scaling groups that point to unavailable resources cannot launch new Amazon Elastic Compute Cloud (Amazon EC2) instances. When properly configured, Auto Scaling causes the number of Amazon EC2 instances to increase seamlessly during demand spikes and decrease automatically during demand lulls. Auto Scaling groups and launch configurations that point to unavailable resources do not operate as intended.')
, ROW ('opQPADkZvH', 'en', 'Amazon RDS Backups', 'Checks for automated backups of Amazon RDS DB instances. By default, backups are enabled with a retention period of 1 day. Backups reduce the risk of unexpected data loss and allow for point-in-time recovery.')
, ROW ('f2iK5R6Dep', 'en', 'Amazon RDS Multi-AZ', 'Checks for DB instances that are deployed in a single Availability Zone. Multi-AZ deployments enhance database availability by synchronously replicating to a standby instance in a different Availability Zone. During planned database maintenance or the failure of a DB instance or Availability Zone, Amazon RDS automatically fails over to the standby so that database operations can resume quickly without administrative intervention. Because Multi-AZ deployments for the SQL Server engine use a different mechanism for synchronization, this check does not examine SQL Server instances.')
, ROW ('CLOG40CDO8', 'en', 'Auto Scaling Group Health Check', 'Examines the health check configuration for Auto Scaling groups. If Elastic Load Balancing is being used for an Auto Scaling group, the recommended configuration is to enable an Elastic Load Balancing health check. If an Elastic Load Balancing health check is not used, Auto Scaling can only act upon the health of the Amazon Elastic Compute Cloud (Amazon EC2) instance and not on the application that is running on the instance.')
, ROW ('BueAdJ7NrP', 'en', 'Amazon S3 Bucket Logging', 'Checks the logging configuration of Amazon Simple Storage Service (Amazon S3) buckets. When server access logging is enabled, detailed access logs are delivered hourly to a bucket that you choose. An access log record contains details about each request, such as the request type, the resources specified in the request, and the time and date the request was processed. By default, bucket logging is not enabled; you should enable logging if you want to perform security audits or learn more about users and usage patterns.')
, ROW ('PPkZrjsH2q', 'en', 'Amazon EBS Provisioned IOPS (SSD) Volume Attachment Configuration', 'Checks for Provisioned IOPS (SSD) volumes that are attached to an Amazon EBS-optimizable Amazon Elastic Compute Cloud (Amazon EC2) instance that is not EBS-optimized. Provisioned IOPS (SSD) volumes in the Amazon Elastic Block Store (Amazon EBS) are designed to deliver the expected performance only when they are attached to an EBS-optimized instance.')
, ROW ('tfg86AVHAZ', 'en', 'Large Number of Rules in an EC2 Security Group', 'Checks each Amazon Elastic Compute Cloud (EC2) security group for an excessive number of rules. If a security group has a large number of rules, performance can be degraded.')
, ROW ('j3DFqYTe29', 'en', 'Large Number of EC2 Security Group Rules Applied to an Instance', 'Checks for Amazon Elastic Compute Cloud (EC2) instances that have a large number of security group rules. Performance can be degraded if an instance has a large number of rules.')
, ROW ('Ti39halfu8', 'en', 'Amazon RDS Idle DB Instances', 'Checks the configuration of your Amazon Relational Database Service (Amazon RDS) for any DB instances that appear to be idle. If a DB instance has not had a connection for a prolonged period of time, you can delete the instance to reduce costs. If persistent storage is needed for data on the instance, you can use lower-cost options such as taking and retaining a DB snapshot. Manually created DB snapshots are retained until you delete them.')
, ROW ('B913Ef6fb4', 'en', 'Amazon Route 53 Alias Resource Record Sets', 'Checks for resource record sets that can be changed to alias resource record sets to improve performance and save money. An alias resource record set routes DNS queries to an AWS resource (for example, an Elastic Load Balancing load balancer or an Amazon S3 bucket) or to another Route 53 resource record set. When you use alias resource record sets, Route 53 routes your DNS queries to AWS resources free of charge. Hosted zones created by AWS services won’t appear in your check results.')
, ROW ('cF171Db240', 'en', 'Amazon Route 53 Name Server Delegations', 'Checks for Amazon Route 53 hosted zones for which your domain registrar or DNS is not using the correct Route 53 name servers. When you create a hosted zone, Route 53 assigns a delegation set of four name servers. The names of these servers are ns-###.awsdns-##.com, .net, .org, and .co.uk, where ### and ## typically represent different numbers. Before Route 53 can route DNS queries for your domain, you must update your registrars name server configuration to remove the name servers that the registrar assigned and add all four name servers in the Route 53 delegation set. For maximum availability, you must add all four Route 53 name servers. Hosted zones created by AWS services won’t appear in your check results.<br/><br/><b>Alert Criteria</b><br/>Yellow: A hosted zone for which the registrar for your domain does not use all four of the Route 53 name servers in the delegation set.<br/><br/><b>Recommended Action</b><br/>Add or update name server records with your registrar or with the current DNS service for your domain to include all four of the name servers in your Route 53 delegation set. To find these values, see <a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/GetInfoAboutHostedZone.html" target="_blank">Getting the Name Servers for a Hosted Zone</a>. For information about adding or updating name server records, see <a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/creating-migrating.html" target="_blank">Creating and Migrating Domains and Subdomains to Amazon Route&nbsp;53</a>.<br/><br/><b>Additional Resources</b><br/><a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/AboutHZWorkingWith.html" target="_blank">Working with Hosted Zones</a> <br/>')
, ROW ('C056F80cR3', 'en', 'Amazon Route 53 High TTL Resource Record Sets', 'Checks for resource record sets that can benefit from having a lower time-to-live (TTL) value. TTL is the number of seconds that a resource record set is cached by DNS resolvers. When you specify a long TTL, DNS resolvers take longer to request updated DNS records, which can cause unnecessary delay in rerouting traffic (for example, when DNS Failover detects and responds to a failure of one of your endpoints). Hosted zones created by AWS services won’t appear in your check results.')
, ROW ('k3J2hns32g', 'en', 'Overutilized Amazon EBS Magnetic Volumes', 'Checks for Amazon Elastic Block Store (EBS) Magnetic volumes that are potentially overutilized and might benefit from a more efficient configuration. A Magnetic volume is designed for applications with moderate or bursty I/O requirements, and the IOPS rate is not guaranteed. It delivers approximately 100 IOPS on average, with a best-effort ability to burst to hundreds of IOPS. For consistently higher IOPS, you can use a Provisioned IOPS (SSD) volume. For bursty IOPS, you can use a General Purpose (SSD) volume. For more information, see <a href="http://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html" target="_blank">Amazon EBS Volume Types</a>.')
, ROW ('796d6f3D83', 'en', 'CloudFront Content Delivery Optimization', 'Checks for cases where data transfer from Amazon Simple Storage Service (Amazon S3) buckets could be accelerated by using Amazon CloudFront, the AWS global content delivery service. When you configure CloudFront to deliver your content, requests for your content are automatically routed to the nearest edge location where content is cached, so it can be delivered to your users with the best possible performance. A high ratio of data transferred out to the data stored in the bucket indicates that you could benefit from using Amazon CloudFront to deliver the data. ')
, ROW ('51fC20e7I2', 'en', 'Amazon Route 53 Latency Resource Record Sets', 'Checks for Amazon Route 53 latency record sets that are configured inefficiently. To allow Amazon Route 53 to route queries to the region with the lowest network latency, you should create latency resource record sets for a particular domain name (such as example.com) in different regions. If you create only one latency resource record set for a domain name, all queries are routed to one region, and you pay extra for latency-based routing without getting the benefits. Hosted zones created by AWS services won’t appear in your check results.')
, ROW ('c9D319e7sG', 'en', 'Amazon Route 53 MX Resource Record Sets and Sender Policy Framework', 'For each MX resource record set, checks that the TXT or SPF resource record set contains a valid SPF record. The record must start with "v=spf1". The SPF record specifies the servers that are authorized to send email for your domain, which helps detect and stop email address spoofing to reduce spam. Route 53 recommends that you use a TXT record instead of an SPF record. Trusted Advisor reports this check as green as long as each MX resource record set has at least one SPF or TXT record.<br/><br/><b>Alert Criteria</b><br/>Yellow: An MX resource record set doesn’t have a TXT or SPF resource record that contains a valid SPF value.<br/><br/><b>Recommended Action</b><br/>For each MX resource record set, create a TXT resource record set that contains a valid SPF value. For more information, see <a href="http://www.open-spf.org/SPF_Record_Syntax" target="_blank">Sender Policy Framework: SPF Record Syntax</a> and <a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/RRSchanges_console.html" target="_blank">Creating Resource Record Sets By Using the Amazon Route 53 Console</a>.<br/><br/><b>Additional Information</b><br/><a href="http://en.wikipedia.org/wiki/Sender_Policy_Framework" target="_blank">Sender Policy Framework</a> (Wikipedia)<br/><a href="http://en.wikipedia.org/wiki/MX_record" target="_blank">MX record</a> (Wikipedia)')
, ROW ('b73EEdD790', 'en', 'Amazon Route 53 Failover Resource Record Sets', 'Checks for Amazon Route 53 failover resource record sets that are misconfigured. When Amazon Route 53 health checks determine that the primary resource is unhealthy, Amazon Route 53 responds to queries with a secondary, backup resource record set. You must create correctly configured primary and secondary resource record sets for failover to work. Hosted zones created by AWS services won’t appear in your check results.<br/><br/><b>Alert Criteria</b><br/>Yellow: A primary failover resource record set does not have a corresponding secondary resource record set.<br/>Yellow: A secondary failover resource record set does not have a corresponding primary resource record set.<br/>Yellow: Primary and secondary resource record sets that have the same name are associated with the same health check.<br/><br/><b>Recommended Action</b><br/>If a failover resource set is missing, create the corresponding resource record set; see <a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/creating-failover-rrsets.html" target="_blank">Creating Failover Resource Record Sets</a>.<br/>If your resource record sets are associated with the same health check, create separate health checks for each one; see <a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/health-checks-creating-deleting.html" target="_blank">Creating, Updating, and Deleting Health Checks</a>.<br/><br/><b>Additional Information</b><br/><a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/dns-failover.html" target="_blank">Amazon Route 53 Health Checks and DNS Failover</a>')
, ROW ('Cb877eB72b', 'en', 'Amazon Route 53 Deleted Health Checks', 'Checks for resource record sets that are associated with health checks that have been deleted. Amazon Route 53 does not prevent you from deleting a health check that is associated with one or more resource record sets. If you delete a health check without updating the associated resource record sets, the routing of DNS queries for your DNS failover configuration will not work as intended. Hosted zones created by AWS services won’t appear in your check results.<br/><br/><b>Alert Criteria</b><br/>Yellow: A resource record set is associated with a health check that has been deleted.<br/><br/><b>Recommended Action</b><br/>Create a new health check and associate it with the resource record set; see <a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/health-checks-creating-deleting.html" target="_blank">Creating, Updating, and Deleting Health Checks</a> and <a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/health-checks-adding-to-rrsets.html" target="_blank">Adding Health Checks to Resource Record Sets</a>.<br/><br/><b>Additional Information</b><br/><a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/dns-failover.html" target="_blank">Amazon Route 53 Health Checks and DNS Failover</a><br/><a href="http://docs.aws.amazon.com/Route53/latest/DeveloperGuide/dns-failover-simple-configs.html" target="_blank">How Health Checks Work in Simple Amazon Route 53 Configurations</a>')
, ROW ('vjafUGJ9H0', 'en', 'AWS CloudTrail Logging', 'Checks for your use of AWS CloudTrail. CloudTrail provides increased visibility into activity in your AWS account by recording information about AWS API calls made on the account. You can use these logs to determine, for example, what actions a particular user has taken during a specified time period or which users have taken actions on a particular resource during a specified time period. Because CloudTrail delivers log files to an Amazon Simple Storage Service (Amazon S3) bucket, CloudTrail must have write permissions for the bucket. If a trail applies to all regions (the default when creating a new trail), the trail appears multiple times in the Trusted Advisor report.')
, ROW ('a2sEc6ILx', 'en', 'ELB Listener Security', 'Checks for load balancers with listeners that do not use recommended security configurations for encrypted communication. AWS recommends using a secure protocol (HTTPS or SSL), up-to-date security policies, and ciphers and protocols that are secure.<br/>When you use a secure protocol for a front-end connection (client to load balancer), the requests are encrypted between your clients and the load balancer, which is more secure.<br/>Elastic Load Balancing provides predefined security policies  with ciphers and protocols that adhere to AWS security best practices. New versions of predefined policies are released as new configurations become available. <br/><br/><b>Alert Criteria</b><br/>Yellow: A load balancer has no listener that uses a secure protocol (HTTPS or SSL). <br/>Yellow: A load balancer listener uses an outdated predefined SSL security policy. <br/>Yellow: A load balancer listener uses a cipher or protocol that is not recommended. <br/>Red: A load balancer listener uses an insecure cipher or protocol.<br/><br/><b>Recommended Action</b><ul><li>If the traffic to your load balancer must be secure, use either the HTTPS or the SSL protocol for the front-end connection.</li><li>Upgrade your load balancer to the latest version of the predefined SSL security policy.</li> <li>Use only the recommended ciphers and protocols.</li> </ul>For more information, see <a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/elb-listener-config.html">Listener Configurations for Elastic Load Balancing</a>.<br/><br/><b>Additional Resources</b><br/><a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/using-elb-listenerconfig-quickref.html">Listener Configurations Quick Reference</a><br/><a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/ssl-config-update.html">Update SSL Negotiation Configuration of Your Load Balancer</a><br/><a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/elb-ssl-security-policy.html">SSL Negotiation Configurations for Elastic Load Balancing</a><br/><a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/elb-security-policy-table.html">SSL Security Policy Table</a><br/>')
, ROW ('xSqX82fQu', 'en', 'ELB Security Groups', 'Checks for load balancers configured with a missing security group or a security group that allows access to ports that are not configured for the load balancer. If a security group associated with a load balancer is deleted, the load balancer does not work as expected. If a security group allows access to ports that are not configured for the load balancer, the risk of loss of data or malicious attacks increases. <br/><br/><b>Alert Criteria</b><br/>Yellow: The inbound rules of an Amazon VPC security group associated with a load balancer allow access to ports that are not defined in the load balancers listener configuration. <br/>Red: A security group associated with a load balancer does not exist. <br/><br/><b>Recommended Action</b><br/>Configure the security group rules to restrict access to only those ports and protocols that are defined in the load balancer listener configuration, plus the ICMP protocol to support Path MTU Discovery. See <a target="_blank" href="https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-listener-config.html">Listeners for Your Classic Load Balancer</a> and <a target="_blank" href="https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-security-groups.html#elb-vpc-security-groups">Security Groups for Load Balancers in a VPC</a>.<br/>If a security group is missing, apply a new security group to the load balancer. Create security group rules that restrict access to only those ports and protocols that are defined in the load balancer listener configuration. See <a target="_blank" href="https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-security-groups.html#elb-vpc-security-groups">Security Groups for Load Balancers in a VPC</a>. <br/><br/><b>Additional Resources</b><br/><a target="_blank" href="https://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/what-is-load-balancing.html">Elastic Load Balancing User Guide</a> <br/><a target="_blank" href="https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-configure-load-balancer.html">Configure Your Classic Load Balancer</a>')
, ROW ('xdeXZKIUy', 'en', 'ELB Cross-Zone Load Balancing', 'With Cross-zone load balancing turned off, there is a risk of service unavailability due to uneven distribution of traffic or backend overloading. This problem can occur when clients incorrectly cache DNS information, or when there are an unequal number of instances in each Availability Zone (for example, if you have taken down some instances for maintenance).<br/><br/><b>Alert Criteria</b><br/>Yellow: Cross-zone load balancing is not enabled for a load balancer.<br/><br/><b>Recommended Action</b><br/>Confirm that the Amazon EC2 instances registered with the load balancer are launched in multiple Availability Zones, and then enable cross-zone load balancing for the load balancer. For more information, see <a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/TerminologyandKeyConcepts.html#AZ-Region">Availability Zones and Regions</a> and <a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/enable-disable-crosszone-lb.html">Enable or Disable Cross-Zone Load Balancing for Your Load Balancer</a>.<br/><br/><b>Additional Resources</b><br/><a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/TerminologyandKeyConcepts.html#request-routing">Request Routing</a><br/><a target="_blank" href="https://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/TerminologyandKeyConcepts.html">Elastic Load Balancing Concepts</a>')
, ROW ('7qGXsKIUw', 'en', 'ELB Connection Draining', 'Checks for load balancers that do not have connection draining enabled. When connection draining is not enabled and you remove (deregister) an Amazon EC2 instance from a load balancer, the load balancer stops routing traffic to that instance and closes the connection. When connection draining is enabled, the load balancer stops sending new requests to the deregistered instance but keeps the connection open to serve active requests.<br/><br/><b>Alert Criteria</b><br/> Yellow: Connection draining is not enabled for a load balancer.<br/><br/> <b>Recommended Action</b><br/>Enable connection draining for the load balancer. For more information, see <a target="_blank" href="http://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/TerminologyandKeyConcepts.html#conn-drain">Connection Draining</a> and <a target="_blank" href="http://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/config-conn-drain.html">Enable or Disable Connection Draining for Your Load Balancer</a>.<br/><br/><b>Additional Resources</b><br/><a target="_blank" href="http://docs.aws.amazon.com/ElasticLoadBalancing/latest/DeveloperGuide/TerminologyandKeyConcepts.html">Elastic Load Balancing Concepts</a>')
, ROW ('N415c450f2', 'en', 'CloudFront Header Forwarding and Cache Hit Ratio', 'Checks the HTTP request headers that CloudFront currently receives from the client and forwards to your origin server. Some headers, such as Date or User-Agent, significantly reduce the cache hit ratio (the proportion of requests that are served from a CloudFront edge cache). This increases the load on your origin and reduces performance because CloudFront must forward more requests to your origin.')
, ROW ('N425c450f2', 'en', 'CloudFront Custom SSL Certificates in the IAM Certificate Store', 'Checks the SSL certificates for CloudFront alternate domain names in the IAM certificate store and alerts you if the certificate is expired, will soon expire, uses outdated encryption, or is not configured correctly for the distribution. When a custom certificate for an alternate domain name expires, browsers that display your CloudFront content might show a warning message about the security of your website. Certificates that are encrypted by using the SHA-1 hashing algorithm are being deprecated by web browsers such as Chrome and Firefox.  If a certificate doesnt contain any domain names that match either Origin Domain Name or the domain name in the Host header of viewer requests, CloudFront returns an HTTP status code 502 (bad gateway) to the user. For more information, see <a href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/SecureConnections.html#CNAMEsAndHTTPS" target="_blank">Using Alternate Domain Names and HTTPS</a>.')
, ROW ('N430c450f2', 'en', 'CloudFront SSL Certificate on the Origin Server', 'Checks your origin server for SSL certificates that are expired, about to expire, missing, or that use outdated encryption. If a certificate is expired, CloudFront responds to requests for your content with HTTP status code 502, Bad Gateway. Certificates that were encrypted by using the SHA-1 hashing algorithm are being deprecated by web browsers such as Chrome and Firefox. Depending on the number of SSL certificates that you have associated with your CloudFront distributions, this check might add a few cents per month to your bill with your web hosting provider, for example, AWS if youre using EC2 or ELB as the origin for your CloudFront distribution. This check does not validate your origin certificate chain or certificate authorities; you can check these in your CloudFront configuration. ')
, ROW ('Bh2xRR2FGH', 'en', 'Amazon EC2 to EBS Throughput Optimization', 'Checks for Amazon EBS volumes whose performance might be affected by the maximum throughput capability of the Amazon EC2 instance they are attached to. To optimize performance, you should ensure that the maximum throughput of an EC2 instance is greater than the aggregate maximum throughput of the attached EBS volumes. This check computes the total EBS volume throughput for each five-minute period in the preceding day (UTC) for each EBS-optimized instance and alerts you if usage in more than half of those periods was greater than 95% of the maximum throughput of the EC2 instance.<br/><br/> <b>Alert Criteria</b><br/> Yellow: In the preceding day (UTC), the aggregate throughput (megabytes/sec) of the EBS volumes attached to the EC2 instance exceeded 95% of the published throughput between the instance and the EBS volumes more than 50% of time.<br/><br/> <b>Recommended Action</b><br/> Compare the maximum throughput of your EBS volumes (see <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html" target="_blank">Amazon EBS Volume Types</a>) with the maximum throughput of the EC2 instance they are attached to (see <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSOptimized.html#ebs-optimization-support" target="_blank">Instance Types That Support EBS Optimization</a>). Consider attaching your volumes to an instance that supports higher throughput to EBS for optimal performance.<br/><br/> <b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html" target="_blank">Amazon EBS Volume Types</a><br/> <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSOptimized.html" target="_blank">Amazon EBS-Optimized Instances</a><br/> <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/monitoring-volume-status.html" target="_blank">Monitoring the Status of Your Volumes</a><br/> <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-attaching-volume.html" target="_blank">Attaching an Amazon EBS Volume to an Instance</a><br/> <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-detaching-volume.html" target="_blank">Detaching an Amazon EBS Volume from an Instance</a><br/> <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-deleting-volume.html" target="_blank">Deleting an Amazon EBS Volume</a> ')
, ROW ('N420c450f2', 'en', 'CloudFront Alternate Domain Names', 'Checks Amazon CloudFront distributions for alternate domain names (CNAMES) that have incorrectly configured DNS settings. If a CloudFront distribution includes alternate domain names, the DNS configuration for the domains must route DNS queries to that distribution.<br/><br/>Note: This check assumes Amazon Route 53 DNS and Amazon CloudFront distribution are configured in the same AWS account. As such the Alert list may include resources otherwise working as expected due to DNS setting outsides of this AWS account.<br/><br/><b>Alert Criteria</b><br/>Yellow: A CloudFront distribution includes alternate domain names, but the DNS configuration is not correctly set up with a CNAME record or an Amazon Route 53 alias resource record.<br/>Yellow: A CloudFront distribution includes alternate domain names, but Trusted Advisor could not evaluate the DNS configuration because there were too many redirects.<br/>Yellow: A CloudFront distribution includes alternate domain names, but Trusted Advisor could not evaluate the DNS configuration for some other reason, most likely because of a timeout.<br/><br/><b>Recommended Action</b><br/>Update the DNS configuration to route DNS queries to the CloudFront distribution; see <a href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/CNAMEs.html" target="_blank">Using Alternate Domain Names (CNAMEs)</a>. If youre using Amazon Route 53 as your DNS service, see <a href="https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/routing-to-cloudfront-distribution.html" target="_blank">Routing Traffic to an Amazon CloudFront Web Distribution by Using Your Domain Name</a>. If the check timed out, try refreshing the check.<br/><br/><b>Additional Resources</b><br/><a target="_blank" href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Introduction.html">Amazon CloudFront Developer Guide</a>')
, ROW ('DqdJqYeRm5', 'en', 'IAM Access Key Rotation', 'Checks for active IAM access keys that have not been rotated in the last 90 days.  When you rotate your access keys regularly, you reduce the chance that a compromised key could be used without your knowledge to access resources. For the purposes of this check, the last rotation date and time is when the access key was created or most recently activated. The access key number and date come from the <b>access_key_1_last_rotated</b> and <b>access_key_2_last_rotated</b> information in the most recent IAM credential report. Because the regeneration frequency of a credential report  is restricted, refreshing this check might not reflect recent changes (for details, see <a target="_blank" href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_getting-report.html">Getting Credential Reports for Your AWS Account</a>).<br/>In order to create and rotate access keys, a user must have the appropriate permissions. For more information, see <a target="_blank" href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_delegate-permissions_examples.html#creds-policies-credentials">Allow Users to Manage Their Own Passwords, Access Keys, and SSH Keys</a>.<br/><br/><b>Alert Criteria</b><br/>Green: The access key is active and has been rotated in the last 90 days.<br/>Yellow: The access key is active and has been rotated in the last 2 years, but more than 90 days ago.<br/>Red: The access key is active and has not been rotated in the last 2 years.<br/><br/><b>Recommended Action</b><br/>Rotate access keys on a regular basis. See <a target="_blank" href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html#Using_RotateAccessKey">Rotating Access Keys</a> and <a target="_blank" href="https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html">Managing Access Keys for IAM Users</a>.<br/><br/><b>Additional Resources</b><br/><a target="_blank" href="https://docs.aws.amazon.com/IAM/latest/UserGuide/best-practices.html">IAM Best Practices</a><br/><a target="_blank" href="https://blogs.aws.amazon.com/security/post/Tx15CIT22V4J8RP/How-to-rotate-access-keys-for-IAM-users">How to rotate access keys for IAM users</a> (AWS blog)')
, ROW ('12Fnkpl8Y5', 'en', 'Exposed Access Keys', 'Checks popular code repositories for access keys that have been exposed to the public and for irregular Amazon Elastic Compute Cloud (Amazon EC2) usage that could be the result of a compromised access key. An access key consists of an access key ID and the corresponding secret access key. Exposed access keys pose a security risk to your account and other users, could lead to excessive charges from unauthorized activity or abuse, and violate the <a target="_blank" href="https://aws.amazon.com/agreement/">AWS Customer Agreement</a>. If your access key is exposed, take immediate action to secure your account. To protect your account from excessive charges, AWS temporarily limits your ability to create certain AWS resources when exposed access keys are identified. This does not make your account secure; it only partially limits the unauthorized usage for which you could be charged. Note: This check does not guarantee the identification of exposed access keys or compromised EC2 instances. You are ultimately responsible for the safety and security of your access keys and AWS resources.   <br/><br/>If a deadline is shown for an access key, AWS may suspend your AWS account if the unauthorized usage is not stopped by that date. If you believe an alert is in error, <a href="https://console.aws.amazon.com/support/home?#/case/create?issueType=customer-service&serviceCode=customer-account&categoryCode=security" target="_blank">contact AWS Support</a>.<br/><br/>The information displayed in Trusted Advisor may not reflect the most recent state of your account. No exposed access keys are marked as resolved until all exposed access keys on the account have been resolved. This data synchronization can take up to one week.<br/><br/><b>Alert Criteria</b><br/>Red: Potentially compromised - AWS has identified an access key ID and corresponding secret access key that have been exposed on the Internet and may have been compromised (used).<br/>Red: Exposed - AWS has identified an access key ID and corresponding secret access key that have been exposed on the Internet.<br/>Red: Suspected - Irregular Amazon EC2 usage indicates that an access key may have been compromised, but it has not been identified as exposed on the Internet.<br/><br/><b>Recommended Action</b><br/>Delete the affected access key as soon as possible. If the key is associated with an IAM user, see <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/ManagingCredentials.html" target="_blank">Managing Access Keys for IAM Users</a>.<br/><br/>Check your account for unauthorized usage. Log in to the <a href="https://console.aws.amazon.com/" target="_blank">AWS Management Console</a> and check each service console for suspicious resources. Pay special attention to running Amazon EC2 instances, Spot Instance requests, access keys, and IAM users. You can also check overall usage on the <a href="https://console.aws.amazon.com/billing/home#/" target="_blank">Billing & Cost Management Dashboard</a>.<br/><br/><b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/general/latest/gr/aws-access-keys-best-practices.html" target="_blank">Best Practices for Managing AWS Access Keys</a><br/><a href="https://docs.aws.amazon.com/general/latest/gr/aws-security-audit-guide.html" target="_blank">AWS Security Audit Guidelines</a>')
, ROW ('G31sQ1E9U', 'en', 'Underutilized Amazon Redshift Clusters', 'Checks your Amazon Redshift configuration for clusters that appear to be underutilized. If an Amazon Redshift cluster has not had a connection for a prolonged period of time or is using a low amount of CPU, you can use lower-cost options such as downsizing the cluster or shutting down the cluster and taking a final snapshot. Final snapshots are retained even after you delete your cluster.<br/><br/><b>Alert Criteria</b><br/>Yellow: A running cluster has not had a connection in the last 7 days.<br/>Yellow: A running cluster had less than 5% cluster-wide average CPU utilization for 99% of the last 7 days.<br/><br/><b>Recommended Action</b><br/>Consider shutting down the cluster and taking a final snapshot, or downsizing the cluster. See <a href="https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html#rs-mgmt-shutdown-delete-cluster" target="_blank">Shutting Down and Deleting Clusters</a> and <a href="https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html#cluster-resize-intro" target="_blank">Resizing a Cluster</a>.<br/><br/><b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/Welcome.html" target="_blank">Amazon CloudWatch Developer Guide</a>')
, ROW ('1e93e4c0b5', 'en', 'Amazon EC2 Reserved Instance Lease Expiration', 'Checks for Amazon EC2 Reserved Instances that are scheduled to expire within the next 30 days or have expired in the preceding 30 days. Reserved Instances do not renew automatically; you can continue using an EC2 instance covered by the reservation without interruption, but you will be charged On-Demand rates. New Reserved Instances can have the same parameters as the expired ones, or you can purchase Reserved Instances with different parameters.<br/>The estimated monthly savings we show is the difference between the On-Demand and Reserved Instance rates for the same instance type.<br/><br/><b>Alert Criteria</b><br/>Yellow: The Reserved Instance lease expires in less than 30 days.<br/>Yellow: The Reserved Instance lease expired in the preceding 30 days.<br/><br/><b>Recommended Action</b><br/>Consider purchasing a new Reserved Instance to replace the one that is nearing the end of its term. For more information, see <a href="https://aws.amazon.com/ec2/purchasing-options/reserved-instances/buyer/" target="_blank">How to Purchase Reserved Instances</a> and <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-concepts-buying.html" target="_blank">Buying Reserved Instances</a>.<br/><br/> <b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/concepts-on-demand-reserved-instances.html" target="_blank">Reserved Instances</a><br/><a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html" target="_blank">Instance Types</a>')
, ROW ('R365s2Qddf', 'en', 'Amazon S3 Bucket Versioning', 'Checks for Amazon Simple Storage Service buckets that do not have versioning enabled, or have versioning suspended. When versioning is enabled, you can easily recover from both unintended user actions and application failures. Versioning allows you to preserve, retrieve, and restore any version of any object stored in a bucket. You can use lifecycle rules to manage all versions of your objects as well as their associated costs by automatically archiving objects to the Glacier storage class or removing them after a specified time period. You can also choose to require multi-factor authentication (MFA) for any object deletions or configuration changes to your buckets. <br/><br/>Versioning cannot be disabled after it has been enabled, but it can be suspended, which prevents new versions of objects from being created. Using versioning can increase your costs for Amazon S3, because you pay for storage of multiple versions of an object.<br/><br/><b>Alert Criteria</b><br/>Green: Versioning is enabled for the bucket.<br/>Yellow: Versioning is not enabled for the bucket.<br/>Yellow: Versioning is suspended for the bucket.<br/><br/><b>Recommended Action</b><br/>Enable bucket versioning on most buckets to prevent accidental deletion or overwriting. See <a href="https://docs.aws.amazon.com/AmazonS3/latest/dev/Versioning.html" target="_blank">Using Versioning</a> and <a href="https://docs.aws.amazon.com/AmazonS3/latest/dev/manage-versioning-examples.html" target="_blank">Enabling Versioning Programmatically</a>. <br/><br/>If bucket versioning is suspended, consider reenabling versioning. For information on working with objects in a versioning-suspended bucket, see <a href="https://docs.aws.amazon.com/AmazonS3/latest/dev/VersionSuspendedBehavior.html" target="_blank">Managing Objects in a Versioning-Suspended Bucket</a>.<br/><br/>When versioning is enabled or suspended, you can define lifecycle configuration rules to mark certain object versions as expired or to permanently remove unneeded object versions. For more information, see <a href="https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html" target="_blank">Object Lifecycle Management</a>. <br/><br/>MFA Delete requires additional authentication when the versioning status of the bucket is changed or when versions of an object are deleted. It requires the user to enter credentials and a code from an approved authentication device. For more information, see <a href="https://docs.aws.amazon.com/AmazonS3/latest/dev/Versioning.html#MultiFactorAuthenticationDelete" target="_blank">MFA Delete</a>.<br/><br/><b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/AmazonS3/latest/UG/BucketOperations.html" target="_blank">Working with Buckets</a>')
, ROW ('0t121N1Ty3', 'en', 'AWS Direct Connect Connection Redundancy', 'Checks for regions that have only one AWS Direct Connect connection. Connectivity to your AWS resources should have two Direct Connect connections configured at all times to provide redundancy in case a device is unavailable.<br/><b>Note:</b> Results for this check are automatically refreshed several times daily, and refresh requests are not allowed. It might take a few hours for changes to appear.<br/><br/><b>Alert Criteria</b><br/>Yellow:  The region has only one Direct Connect connection.<br/><br/><b>Recommended Action</b><br/>Configure an additional Direct Connect connection in this region to protect against device unavailability. For more information, see <a target="_blank" href="https://docs.aws.amazon.com/directconnect/latest/UserGuide/getting_started.html">Configure Redundant Connections with AWS Direct Connect</a>. To protect against site unavailability and add location redundancy, configure the additional Direct Connect connection to a different Direct Connect location.<br/><br/><b>Additional Resources</b><br/><a target="_blank" href="https://docs.aws.amazon.com/directconnect/latest/UserGuide/getting_started.html">Getting Started with AWS Direct Connect</a><br/><a target="_blank" href="https://aws.amazon.com/directconnect/faqs/">AWS Direct Connect FAQs</a> ')
, ROW ('8M012Ph3U5', 'en', 'AWS Direct Connect Location Redundancy', 'Checks for regions with one or more AWS Direct Connect connections and only one AWS Direct Connect location. Connectivity to your AWS resources should have Direct Connect connections configured to different Direct Connect locations to provide redundancy in case a location is unavailable.<br/><b>Note:</b> Results for this check are automatically refreshed several times daily, and refresh requests are not allowed. It might take a few hours for changes to appear.<br/><br/><b>Alert Criteria</b><br/>Yellow:  The Direct Connect connections in the region are not configured to different locations.<br/><br/><b>Recommended Action</b><br/>Configure a Direct Connect connection that uses a different Direct Connect location to protect against location unavailability. For more information, see <a target="_blank" href="https://docs.aws.amazon.com/directconnect/latest/UserGuide/getting_started.html">Getting Started with AWS Direct Connect</a>.<br/><br/><b>Additional Resources</b><br/><a target="_blank" href="https://docs.aws.amazon.com/directconnect/latest/UserGuide/getting_started.html">Getting Started with AWS Direct Connect</a><br/><a target="_blank" href="https://aws.amazon.com/directconnect/faqs/">AWS Direct Connect FAQs</a>')
, ROW ('4g3Nt5M1Th', 'en', 'AWS Direct Connect Virtual Interface Redundancy', 'Checks for virtual private gateways with Direct Connect virtual interfaces (VIFs) that are not configured on at least two Direct Connect connections. Connectivity to your virtual private gateway should have multiple virtual interfaces configured across multiple Direct Connect connections and locations to provide redundancy in case a device or location is unavailable. <br/><b>Note:</b> Results for this check are automatically refreshed several times daily, and refresh requests are not allowed. It might take a few hours for changes to appear.<br/><br/><b>Alert Criteria</b><br/>Yellow:  A virtual private gateway has less than two virtual interfaces, or the interfaces are not configured to multiple Direct Connect connections. <br/><br/><b>Recommended Action</b><br/>Configure at least two virtual interfaces that are configured to two Direct Connect connections to protect against device or location unavailability. See <a target="_blank" href="https://docs.aws.amazon.com/directconnect/latest/UserGuide/getstarted.html#createvirtualinterface">Create a Virtual Interface.</a><br/><br/><b>Additional Resources</b><br/><a target="_blank" href="https://docs.aws.amazon.com/directconnect/latest/UserGuide/getting_started.html">Getting Started with AWS Direct Connect</a><br/><a target="_blank" href="https://aws.amazon.com/directconnect/faqs/">AWS Direct Connect FAQs</a> <br/><a target="_blank" href="https://docs.aws.amazon.com/directconnect/latest/UserGuide/WorkingWithVirtualInterfaces.html">Working With AWS Direct Connect Virtual Interfaces</a>')
, ROW ('xuy7H1avtl', 'en', 'Amazon Aurora DB Instance Accessibility', 'Checks for cases where an Amazon Aurora DB cluster has both private and public instances. When your primary instance fails, a replica can be promoted to a primary instance. If that replica is private, users who have only public access would no longer be able to connect to the database after failover. Its best practice for all the DB instances in a cluster to have the same accessibility.<br/><br/><b>Alert Criteria</b><br/>Yellow: The instances in an Aurora DB cluster have different accessibility (a mix of public and private).<br/><br/><b>Recommended Action</b><br/>Modify the <b>Publicly Accessible</b> setting of the instances in the DB cluster so that they are all either public or private. For details, see the instructions for MySQL instances at <a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ModifyInstance.MySQL.html" target="_blank">Modifying a DB Instance Running the MySQL Database Engine</a>.<br/><br/><b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Aurora.Managing.html#Aurora.Managing.FaultTolerance" target="_blank">Fault Tolerance for an Aurora DB Cluster</a>')
, ROW ('ePs02jT06w', 'en', 'Amazon EBS Public Snapshots', 'Checks the permission settings for your Amazon Elastic Block Store (Amazon EBS) volume snapshots and alerts you if any snapshots are marked as public. When you make a snapshot public, you give all AWS accounts and users access to all the data on the snapshot. If you want to share a snapshot with particular users or accounts, mark the snapshot as private, and then specify the user or accounts you want to share the snapshot data with. <b>Note</b>: Results for this check are automatically refreshed several times daily, and refresh requests are not allowed. It might take a few hours for changes to appear.<br/><br/><b>Alert Criteria</b><br/>Red: The EBS volume snapshot is marked as public.<br/><br/><b>Recommended Action</b><br/>Unless you are certain you want to share all the data in the snapshot with all AWS accounts and users, modify the permissions: mark the snapshot as private, and then specify the accounts that you want to give permissions to. For more information, see <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-modifying-snapshot-permissions.html" target="_blank">Sharing an Amazon EBS Snapshot</a>. Note: For temporary technical reasons, items in this check cannot be excluded from view in the Trusted Advisor console.To modify permissions for your snapshots directly, you can use a runbook in the AWS Systems Manager console. For more information, see <a href="https://docs.aws.amazon.com/systems-manager-automation-runbooks/latest/userguide/automation-awssupport-modifyebssnapshotpermission.html" target="_blank">AWSSupport-ModifyEBSSnapshotPermission</a>.<br/><br/> <b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSSnapshots.html" target="_blank">Amazon EBS Snapshots</a>')
, ROW ('rSs93HQwa1', 'en', 'Amazon RDS Public Snapshots', 'Checks the permission settings for your Amazon Relational Database Service (Amazon RDS) DB snapshots and alerts you if any snapshots are marked as public. When you make a snapshot public, you give all AWS accounts and users access to all the data on the snapshot. If you want to share a snapshot with particular users or accounts, mark the snapshot as private, and then specify the user or accounts you want to share the snapshot data with. <b>Note</b>: Results for this check are automatically refreshed several times daily, and refresh requests are not allowed. It might take a few hours for changes to appear.<br/><br/><b>Alert Criteria</b><br/>Red: The RDS  snapshot is marked as public.<br/><br/><b>Recommended Action</b><br/>Unless you are certain you want to share all the data in the snapshot with all AWS accounts and users, modify the permissions: mark the snapshot as private, and then specify the accounts that you want to give permissions to. For more information, see <a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_ShareSnapshot.html" target="_blank">Sharing a DB Snapshot or DB Cluster Snapshot</a>. Note: For temporary technical reasons, items in this check cannot be excluded from view in the Trusted Advisor console.To modify permissions for your snapshots directly, you can use a runbook in the AWS Systems Manager console. For more information, see <a href="https://docs.aws.amazon.com/systems-manager-automation-runbooks/latest/userguide/automation-awssupport-modifyrdssnapshotpermission.html" target="_blank">AWSSupport-ModifyRDSSnapshotPermission</a>.<br/><br/> <b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_CommonTasks.BackupRestore.html" target="_blank">Backing Up and Restoring Amazon RDS DB Instances</a>')
, ROW ('0Xc6LMYG8P', 'en', 'EC2 On-Demand Instances', 'Checks for usage that is more than 80% of the EC2 On-Demand Instances Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('hJ7NN0l7J9', 'en', 'SES Daily Sending Quota', 'Checks for usage that is more than 80% of the SES Daily Sending Quota Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('tV7YY0l7J9', 'en', 'EBS Provisioned IOPS (SSD) Volume Aggregate IOPS', 'Checks for usage that is more than 80% of the EBS Provisioned IOPS (SSD) Volume Aggregate IOPS Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('gI7MM0l7J9', 'en', 'EBS Provisioned IOPS SSD (io1) Volume Storage', 'Checks for usage that is more than 80% of the EBS Provisioned IOPS SSD (io1) Volume Storage Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('eI7KK0l7J9', 'en', 'EBS Active Snapshots', 'Checks for usage that is more than 80% of the EBS Active Snapshots Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('dH7RR0l6J9', 'en', 'EBS General Purpose SSD (gp2) Volume Storage', 'Checks for usage that is more than 80% of the EBS General Purpose SSD (gp2) Volume Storage Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('cG7HH0l7J9', 'en', 'EBS Magnetic (standard) Volume Storage', 'Checks for usage that is more than 80% of the EBS Magnetic (standard) Volume Storage Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('aW9HH0l8J6', 'en', 'EC2-Classic Elastic IP Addresses', 'Checks for usage that is more than 80% of the EC2-Classic Elastic IP Addresses Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('iH7PP0l7J9', 'en', 'EC2 Reserved Instance Leases', 'Checks for usage that is more than 80% of the EC2 Reserved Instance Leases Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('bW7HH0l7J9', 'en', 'Kinesis Shards per Region', 'Checks for usage that is more than 80% of the Kinesis Shards per Region Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('gW7HH0l7J9', 'en', 'CloudFormation Stacks', 'Checks for usage that is more than 80% of the CloudFormation Stacks Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('aW7HH0l7J9', 'en', 'Auto Scaling Launch Configurations', 'Checks for usage that is more than 80% of the Auto Scaling Launch Configurations Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('fW7HH0l7J9', 'en', 'Auto Scaling Groups', 'Checks for usage that is more than 80% of the Auto Scaling Groups Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('jL7PP0l7J9', 'en', 'VPC', 'Checks for usage that is more than 80% of the VPC Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('kM7QQ0l7J9', 'en', 'VPC Internet Gateways', 'Checks for usage that is more than 80% of the VPC Internet Gateways Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('lN7RR0l7J9', 'en', 'EC2-VPC Elastic IP Address', 'Checks for usage that is more than 80% of the EC2-VPC Elastic IP Address Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('nO7SS0l7J9', 'en', 'IAM Instance Profiles', 'Checks for usage that is more than 80% of the IAM Instance Profiles Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('oQ7TT0l7J9', 'en', 'IAM Roles', 'Checks for usage that is more than 80% of the IAM Roles Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('pR7UU0l7J9', 'en', 'IAM Policies', 'Checks for usage that is more than 80% of the IAM Policies Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('qS7VV0l7J9', 'en', 'IAM Users', 'Checks for usage that is more than 80% of the IAM Users Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('rT7WW0l7J9', 'en', 'IAM Server Certificates', 'Checks for usage that is more than 80% of the IAM Server Certificates Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('sU7XX0l7J9', 'en', 'IAM Group', 'Checks for usage that is more than 80% of the IAM Group Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('iK7OO0l7J9', 'en', 'ELB Classic Load Balancers', 'Checks for usage that is more than 80% of the ELB Classic Load Balancers. Application Load Balancers and Network Load Balancers have a separate limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.<br/>')
, ROW ('7fuccf1Mx7', 'en', 'RDS Cluster Roles', 'Checks for usage that is more than 80% of the RDS Cluster Roles Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('jtlIMO3qZM', 'en', 'RDS Cluster Parameter Groups', 'Checks for usage that is more than 80% of the RDS Cluster Parameter Groups Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('gjqMBn6pjz', 'en', 'RDS Clusters', 'Checks for usage that is more than 80% of the RDS Clusters Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('UUDvOa5r34', 'en', 'RDS Reserved Instances', 'Checks for usage that is more than 80% of the RDS Reserved Instances Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('jEhCtdJKOY', 'en', 'RDS Subnets per Subnet Group', 'Checks for usage that is more than 80% of the RDS Subnets per Subnet Group Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('dYWBaXaaMM', 'en', 'RDS Subnet Groups', 'Checks for usage that is more than 80% of the RDS Subnet Groups Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('3Njm0DJQO9', 'en', 'RDS Option Groups', 'Checks for usage that is more than 80% of the RDS Option Groups Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('keAhfbH5yb', 'en', 'RDS Event Subscriptions', 'Checks for usage that is more than 80% of the RDS Event Subscriptions Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('dV84wpqRUs', 'en', 'RDS DB Manual Snapshots', 'Checks for usage that is more than 80% of the RDS DB Manual Snapshots Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('P1jhKWEmLa', 'en', 'RDS Total Storage Quota', 'Checks for usage that is more than 80% of the RDS Total Storage Quota Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('jEECYg2YVU', 'en', 'RDS DB Parameter Groups', 'Checks for usage that is more than 80% of the RDS DB Parameter Groups Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('pYW8UkYz2w', 'en', 'RDS Read Replicas per Master', 'Checks for usage that is more than 80% of the RDS Read Replicas per Master Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('gfZAn3W7wl', 'en', 'RDS DB Security Groups', 'Checks for usage that is more than 80% of the RDS DB Security Groups Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('XG0aXHpIEt', 'en', 'RDS DB Instances', 'Checks for usage that is more than 80% of the RDS DB Instances Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('dBkuNCvqn5', 'en', 'RDS Max Auths per Security Group', 'Checks for usage that is more than 80% of the RDS Max Auths per Security Group Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('wH7DD0l3J9', 'en', 'EBS Throughput Optimized HDD (st1) Volume Storage', 'Checks for usage that is more than 80% of the EBS Throughput Optimized HDD (st1) Volume Storage Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('gH5CC0e3J9', 'en', 'EBS Cold HDD (sc1) Volume Storage', 'Checks for usage that is more than 80% of the EBS Cold HDD (sc1) Volume Storage Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('6gtQddfEw6', 'en', 'DynamoDB Read Capacity', 'Checks for usage that is more than 80% of the DynamoDB Provisioned Throughput Limit for Reads per Account. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('c5ftjdfkMr', 'en', 'DynamoDB Write Capacity', 'Checks for usage that is more than 80% of the DynamoDB Provisioned Throughput Limit for Writes per Account. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('ru4xfcdfMr', 'en', 'Route 53 Max Health Checks', 'Checks for usage that is more than 80% of the Route 53 Health Checks Limit per account. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('dx3xfcdfMr', 'en', 'Route 53 Hosted Zones', 'Checks for usage that is more than 80% of the Route 53 Hosted Zones Limit per account. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('ty3xfcdfMr', 'en', 'Route 53 Reusable Delegation Sets', 'Checks for usage that is more than 80% of the Route 53 Reusable Delegation Sets Limit per account. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('dx3xfbjfMr', 'en', 'Route 53 Traffic Policies', 'Checks for usage that is more than 80% of the Route 53 Traffic Policies Limit per account. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('dx8afcdfMr', 'en', 'Route 53 Traffic Policy Instances', 'Checks for usage that is more than 80% of the Route 53 Traffic Policy Instances Limit per account. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('cX3c2R1chu', 'en', 'Amazon EC2 Reserved Instances Optimization', 'A significant part of using AWS involves balancing your Reserved Instance (RI) usage and your On-Demand instance usage. We provide recommendations on which RIs will help reduce costs incurred from using On-Demand instances.<br/>AWS generates these recommendations by analyzing your On-Demand usage for the past 30 days, and then categorizing the usage into eligible categories for reservations. We then simulate every combination of reservations in the generated category of usage in order to identify the best number of each type of RI to purchase to maximize your savings. This check covers recommendations based on Standard Reserved Instances with partial upfront payment option. This check is not available to accounts linked in Consolidated Billing. Recommendations are only available for the Paying Account.<br/><br/><b>Alert Criteria</b><br/>Yellow: Optimizing the use of partial upfront RIs can help reduce costs.<br/><br/><b>Recommended Action</b><br/>See the <a href="https://aws.amazon.com/aws-cost-management/aws-cost-explorer/" target="_blank">Cost Explorer</a> page for more detailed and customized recommendations. Additionally, refer to the <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ri-market-general.html#ri-market-buying-guide" target="_blank">buying guide</a> to understand how to purchase RIs and the options available.<br/><br/><b>Additional Resources</b><br/>Information on RIs and how they can save you money can be found <a href="https://aws.amazon.com/ec2/pricing/reserved-instances/" target="_blank">here</a>.<br/>For more information on this recommendation, see <a href="https://aws.amazon.com/premiumsupport/technology/trusted-advisor/faqs/#Reserved_Instance_Optimization_Check_Questions" target="_blank">Reserved Instance Optimization Check Questions</a> in the Trusted Advisor FAQs.')
, ROW ('EM8b3yLRTr', 'en', 'ELB Application Load Balancers', 'Checks for usage that is more than 80% of the ELB Application Load Balancers Limit. Classic Load Balancers and Network Load Balancers have separate limits. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.<br/>')
, ROW ('8wIqYSt25K', 'en', 'ELB Network Load Balancers', 'Checks for usage that is more than 80% of the ELB Network Load Balancers Limit. Classic Load Balancers and Application Load Balancers have separate limits. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.<br/>')
, ROW ('vZ2c2W1srf', 'en', 'Savings Plan', 'Checks your usage of EC2, Fargate, and Lambda over the last 30 days and provides Savings Plan purchase recommendations, which allows you to commit to a consistent usage amount measured in $/hour for a one or three year term in exchange for discounted rates. These are sourced from AWS Cost Explorer which can be used to get more detailed recommendation information, or to purchase a savings plan. These recommendations should be considered an alternative to your RI recommendations and choosing to act fully on both sets of recommendations would likely lead to over commitment. This check is not available to accounts linked in Consolidated Billing. Recommendations are only available for the Paying Account. <br/><br/><b>Alert Criteria</b><br/>Yellow: Optimizing the purchase of Savings Plans can help reduce costs.<br/><br/><b>Recommended Action</b><br/>See the <a href="https://console.aws.amazon.com/billing/home?/costexplorer#/costexplorer/" target="_blank">Cost Explorer</a> page for more detailed and customized recommendations and to purchase Savings Plans. <br/><br/><b>Additional Resources</b><br/>Savings Plan <a href="https://docs.aws.amazon.com/savingsplans/latest/userguide/what-is-savings-plans.html" target="_blank">User Guide</a><br/>Savings Plan <a href="https://aws.amazon.com/savingsplans/faq/" target="_blank">FAQ</a>')
, ROW ('h3L1otH3re', 'en', 'Amazon ElastiCache Reserved Node Optimization', 'Checks your usage of ElastiCache and provides recommendations on purchase of Reserved Nodes to help reduce costs incurred from using ElastiCache On-Demand. AWS generates these recommendations by analyzing your On-Demand usage for the past 30 days. We then simulate every combination of reservations in the generated category of usage in order to identify the best number of each type of Reserved Node to purchase to maximize your savings. This check covers recommendations based on partial upfront payment option with 1-year or 3-year commitment. This check is not available to accounts linked in Consolidated Billing. Recommendations are only available for the Paying Account.')
, ROW ('1qw23er45t', 'en', 'Amazon Redshift Reserved Node Optimization', 'Checks your usage of Redshift and provides recommendations on purchase of Reserved Nodes to help reduce costs incurred from using Redshift On-Demand. AWS generates these recommendations by analyzing your On-Demand usage for the past 30 days. We then simulate every combination of reservations in the generated category of usage in order to identify the best number of each type of Reserved Nodes to purchase to maximize your savings. This check covers recommendations based on partial upfront payment option with 1-year or 3-year commitment. This check is not available to accounts linked in Consolidated Billing. Recommendations are only available for the Paying Account.<br/><br/><b>Alert Criteria</b><br/>Yellow: Optimizing the purchase of Redshift Reserved Nodes can help reduce costs.<br/><br/><b>Recommended Action</b><br/>See the <a href="https://console.aws.amazon.com/billing/home?/costexplorer#/costexplorer" target="_blank">Cost Explorer</a> page for more detailed recommendations, customization options (e.g. look-back period, payment option, etc.) and to purchase Redshift Reserved Nodes.<br/><br/><b>Additional Resources</b><br/>Information on Redshift Reserved Nodes and how they can save you money can be found <a href="http://docs.aws.amazon.com/redshift/latest/mgmt/purchase-reserved-node-instance.html" target="_blank">here</a>.')
, ROW ('1qazXsw23e', 'en', 'Amazon Relational Database Service (RDS) Reserved Instance Optimization', 'Checks your usage of RDS and provides recommendations on purchase of Reserved Instances to help reduce costs incurred from using RDS On-Demand. AWS generates these recommendations by analyzing your On-Demand usage for the past 30 days. We then simulate every combination of reservations in the generated category of usage in order to identify the best number of each type of Reserved Instance to purchase to maximize your savings. This check covers recommendations based on partial upfront payment option with 1-year or 3-year commitment. This check is not available to accounts linked in Consolidated Billing. Recommendations are only available for the Paying Account.<br/><br/><b>Alert Criteria</b><br/>Yellow: Optimizing the purchase of RDS Reserved Instances can help reduce costs.<br/><br/><b>Recommended Action</b><br/>See the <a href="http://console.aws.amazon.com/billing/home?/costexplorer#/costexplorer" target="_blank">Cost Explorer</a> page for more detailed recommendations, customization options (e.g. look-back period, payment option, etc.) and to purchase RDS Reserved Instances.<br/><br/><b>Additional Resources</b><br/>Information on RDS Reserved Instances and how they can save you money can be found <a href="http://aws.amazon.com/rds/reserved-instances/" target="_blank">here</a>.')
, ROW ('7ujm6yhn5t', 'en', 'Amazon OpenSearch Service Reserved Instance Optimization', 'Checks your usage of Amazon OpenSearch Service (successor to Amazon Elasticsearch Service) and provides recommendations on purchase of Reserved Instances to help reduce costs incurred from using Amazon OpenSearch Service On-Demand. AWS generates these recommendations by analyzing your On-Demand usage for the past 30 days. We then simulate every combination of reservations in the generated category of usage in order to identify the best number of each type of Reserved Instance to purchase to maximize your savings. This check covers recommendations based on partial upfront payment option with 1-year or 3-year commitment. This check is not available to accounts linked in Consolidated Billing. Recommendations are only available for the Paying Account.')
, ROW ('L4dfs2Q4C5', 'en', 'AWS Lambda Functions Using Deprecated Runtimes', 'Checks for Lambda functions that are configured to use a runtime that is approaching deprecation or is deprecated. Deprecated runtimes are not eligible for security updates or technical support.<br/><b>Notes:</b>')
, ROW ('L4dfs2Q3C3', 'en', 'AWS Lambda Functions with Excessive Timeouts', 'Checks for Lambda functions with high timeout rates that may result in high cost. Lambda charges based on execution time for your function and number of requests for your function. Function timeouts result in function errors that may cause retries that incur additional request and execution time charges.<br/><b>Note:</b> Results for this check are automatically refreshed several times daily, and refresh requests are not allowed. It might take a few hours for changes to appear.<br/><br/><b>Alert Criteria</b><br/>Yellow: Functions where > 10% of invocations end in an error due to a timeout on any given day within the last 7 days.<br/><br/><b>Recommended Action</b><br/>Inspect function logging and X-ray traces to determine the contributor to the high function duration. Implement logging in your code at relevant parts, such as before or after API calls or database connections. By default, AWS SDK clients timeouts may be longer than the configured function duration. Adjust API and SDK connection clients to retry or fail within the function timeout. If the expected duration is longer than the configured timeout, you can increase the timeout setting for the function. For more information, see <a href="https://docs.aws.amazon.com/lambda/latest/dg/lambda-monitoring.html" target="blank">Monitoring and troubleshooting Lambda applications</a>.<br/><br/><b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/lambda-monitoring.html" target="blank">Monitoring and troubleshooting Lambda applications</a><br/><a href="https://aws.amazon.com/premiumsupport/knowledge-center/lambda-function-retry-timeout-sdk/" target="blank">Lambda Function Retry Timeout SDK</a><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/services-xray.html" target="blank">Using AWS Lambda with AWS X-Ray</a><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/monitoring-cloudwatchlogs.html" target="blank">Accessing Amazon CloudWatch logs for AWS Lambda</a><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/samples-errorprocessor.html" target="blank">Error Processor Sample Application for AWS Lambda</a><br/>')
, ROW ('L4dfs2Q3C2', 'en', 'AWS Lambda Functions with High Error Rates', 'Checks for Lambda functions with high error rates that may result in high cost. Lambda charges based on the number of requests and aggregate execution time for your function. Function errors may cause retries that incur additional charges.<br/><b>Note:</b> Results for this check are automatically refreshed several times daily, and refresh requests are not allowed. It might take a few hours for changes to appear.<br/><br/><b>Alert Criteria</b><br/>Yellow: Functions where > 10% of invocations end in error on any given day within the last 7 days.<br/><br/><b>Recommended Action</b><br/>Consider the following guidelines to reduce errors. Function errors include errors returned by the functions code and errors returned by the functions runtime. To help you troubleshoot Lambda errors, Lambda integrates with services like Amazon CloudWatch and AWS X-Ray. You can use a combination of logs, metrics, alarms, and X-ray tracing to quickly detect and identify issues in your function code, API, or other resources that support your application. For more information, see <a href="https://docs.aws.amazon.com/lambda/latest/dg/lambda-monitoring.html" target="blank">Monitoring and troubleshooting Lambda applications</a>. For more information on handling errors with specific runtimes, see <a href="https://docs.aws.amazon.com/lambda/latest/dg/invocation-retries.html" target="blank">Error handling and automatic retries in AWS Lambda</a>. For additional troubleshooting, see <a href="https://docs.aws.amazon.com/lambda/latest/dg/lambda-troubleshooting.html" target="blank">Troubleshooting issues in Lambda</a>.You can also choose from an ecosystem of monitoring and observability tools provided by AWS Lambda partners. For additional information about Partners, see <a href="https://aws.amazon.com/lambda/partners/?partner-solutions-cards.sort-by=item.additionalFields.partnerNameLower&partner-solutions-cards.sort-order=asc" target="blank">AWS Lambda Partners</a>.<br/><br/><b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/invocation-retries.html" target="blank">Error Handling and Automatic  Retries in AWS Lambda</a><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/lambda-monitoring.html" target="blank">Monitoring and Troubleshooting Lambda applications</a><br/><a href="https://aws.amazon.com/premiumsupport/knowledge-center/lambda-function-retry-timeout-sdk/" target="blank">Lambda Function Retry Timeout SDK</a><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/lambda-troubleshooting.html" target="blank">Troubleshooting  issues in Lambda</a><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/API_Invoke.html#API_Invoke_Errors" target="blank">API Invoke Errors</a><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/samples-errorprocessor.html" target="blank">Error Processor Sample Application for AWS Lambda</a><br/>')
, ROW ('L4dfs2Q4C6', 'en', 'AWS Lambda VPC-enabled Functions without Multi-AZ Redundancy', 'Checks for VPC-enabled Lambda functions that are vulnerable to service interruption in a single availability zone. It is recommended for VPC-enabled functions to be connected to multiple availability zones for high availability.<br/><b>Note:</b> Results for this check are automatically refreshed several times daily, and refresh requests are not allowed. It might take a few hours for changes to appear.<br/><br/><b>Alert Criteria</b><br/>Yellow: A VPC-enabled Lambda function connected to subnets in a single Availability Zone.<br/><br/><b>Recommended Action</b><br/>When configuring functions for access to your VPC, choose subnets in multiple Availability Zones to ensure high availability.<br/><br/><b>Additional Resources</b><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html" target="blank">Configuring a Lambda function to access resources in a VPC</a><br/><a href="https://docs.aws.amazon.com/lambda/latest/dg/security-resilience.html" target="blank">Resilience in AWS Lambda</a><br/>')
, ROW ('dH7RR0l6J3', 'en', 'EBS General Purpose SSD (gp3) Volume Storage', 'Checks for usage that is more than 80% of the EBS General Purpose SSD (gp3) Volume Storage Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('gI7MM0l7J2', 'en', 'EBS Provisioned IOPS SSD (io2) Volume Storage', 'Checks for usage that is more than 80% of the EBS Provisioned IOPS SSD (io2) Volume Storage Limit. Values are based on a snapshot, so your current usage might differ. Limit and usage data can take up to 24 hours to reflect any changes. In cases where limits have been recently increased, you may temporarily see utilization that exceeds the limit.')
, ROW ('Cm24dfsM12', 'en', 'Amazon Comprehend Underutilized Endpoints', 'Checks the throughput configuration of your endpoints. This check alerts you when endpoints are not actively used for real-time inference requests. An endpoint that isn’t used for more than 15 consecutive days is considered underutilized. All endpoints accrue charges based on both the throughput set and the length of time that the endpoint is active.<br/><b>Note:</b> This check is automatically refreshed once a day.<br/><br/><b>Alert Criteria</b><br/>Yellow: The endpoint is active, but hasn’t been used for real-time inference requests in the past 15 days.<br/><br/><b>Recommended Action</b><br/>If the endpoint hasn’t been used in the past 15 days, we recommend that you define a scaling policy for the resource by using <a href="https://docs.aws.amazon.com/comprehend/latest/dg/comprehend-autoscaling.html" target="blank">Application Autoscaling.</a><br/>If the endpoint has a scaling policy defined and hasn’t been used in the past 30 days, consider deleting the endpoint and using asynchronous inference. For more information, see <a href="https://docs.aws.amazon.com/comprehend/latest/dg/manage-endpoints-delete.html" target="blank">Deleting an endpoint with Amazon Comprehend</a>.')
, ROW ('Cm24dfsM13', 'en', 'Amazon Comprehend Endpoint Access Risk', 'Checks the AWS Key Management Service (AWS KMS) key permissions for an endpoint where the underlying model was encrypted by using customer managed keys. If the customer managed key is disabled or the key policy was changed to alter the allowed permissions for Amazon Comprehend, the endpoint availability might be affected.<br/><b>Note:</b> This check is automatically refreshed multiple times a day. It might take a few hours for the latest results to appear.<br/><br/><b>Alert Criteria</b><br/>Red: The customer managed key is disabled or the key policy was changed to alter the allowed permissions for Amazon Comprehend access.<br/><br/><b>Recommended Action</b><br/>If the customer managed key was disabled, we recommend that you enable it. For more information, see <a href="https://docs.aws.amazon.com/kms/latest/developerguide/enabling-keys.html" target="blank">Enabling keys</a>. If the key policy was altered and you want to keep using the endpoint, we recommend that you update the KMS key policy. For more information, see <a href="https://docs.aws.amazon.com/kms/latest/developerguide/key-policy-modifying.html" target="blank">Changing a key policy</a>.')
, ROW ('Wxdfp4B1L1', 'en', 'AWS Well-Architected high risk issues for cost optimization', 'Checks for high risk issues (HRIs) for your workloads in the cost optimization pillar. This check is based on your AWS-Well Architected reviews. Your check results depend on whether you completed the workload evaluation with AWS Well-Architected.<br/><br/><b>Alert Criteria</b><br/>Red: At least one active high risk issue was identified in the cost optimization pillar for AWS Well-Architected.')
, ROW ('Wxdfp4B1L2', 'en', 'AWS Well-Architected high risk issues for performance efficiency', 'Checks for high risk issues (HRIs) for your workloads in the performance pillar. This check is based on your AWS-Well Architected reviews. Your check results depend on whether you completed the workload evaluation with AWS Well-Architected.<br/><br/><b>Alert Criteria</b><br/>Red: At least one active high risk issue was identified in the performance pillar for AWS Well-Architected.')
, ROW ('Wxdfp4B1L3', 'en', 'AWS Well-Architected high risk issues for security', 'Checks for high risk issues (HRIs) for your workloads in the security pillar. This check is based on your AWS-Well Architected reviews. Your check results depend on whether you completed the workload evaluation with AWS Well-Architected.<br/><br/><b>Alert Criteria</b><br/>Red: At least one active high risk issue was identified in the security pillar for AWS Well-Architected.')
, ROW ('Wxdfp4B1L4', 'en', 'AWS Well-Architected high risk issues for reliability', 'Checks for high risk issues (HRIs) for your workloads in the Reliability pillar. This check is based on your AWS-Well Architected reviews. Your check results depend on whether you completed the workload evaluation with AWS Well-Architected.<br/><br/><b>Alert Criteria</b><br/>Red: At least one active high risk issue was identified in the reliability pillar for AWS Well-Architected.')
, ROW ('Qsdfp3A4L1', 'en', 'Amazon EC2 instances over-provisioned for Microsoft SQL Server', 'Checks your Amazon Elastic Compute Cloud (Amazon EC2) instances that are running SQL Server in the past 24 hours. An SQL Server database has a compute capacity limit for each instance. An instance with SQL Server Standard edition can use up to 48 vCPUs. An instance with SQL Server Web can use up to 32 vCPUs. This check alerts you if an instance exceeds this vCPU limit.If your instance is over-provisioned, you pay full price without realizing an improvement in performance. You can manage the number and size of your instances to help lower costs. Estimated monthly savings are calculated by using the same instance family with the maximum number of vCPUs that an SQL Server instance can use and the On-Demand pricing. Actual savings will vary if you’re using Reserved Instances (RI) or if the instance isn’t running for a full day.<br/><br/><b>Alert Criteria</b><br/>Red: An instance with SQL Server Standard edition has more than 48 vCPUs.<br/>Red: An instance with SQL Server Web edition has more than 32 vCPUs.<br/><br/><b>Recommended Action</b><br/>For SQL Server Standard edition, consider changing to an instance in the same instance family with 48 vCPUs. For SQL Server Web edition, consider changing to an instance in the same instance family with 32 vCPUs. If it is memory intensive, consider changing to memory optimized R5 instances. For more information, see <a href="https://d1.awsstatic.com/whitepapers/best-practices-for-deploying-microsoft-sql-server-on-aws.pdf?did=wp_card&trk=wp_card" target="blank">Best Practices for Deploying Microsoft SQL Server on Amazon EC2.</a><br/><br/><b>Additional Resources</b><br/><a href="https://aws.amazon.com/sql/" target="blank">Microsoft SQL Server on AWS</a><br/>You can use <a href="https://aws.amazon.com/launchwizard/" target="blank">Launch Wizard</a> to simplify your SQL Server deployment on EC2.<br/>')
, ROW ('Qsdfp3A4L2', 'en', 'Amazon EC2 instances consolidation for Microsoft SQL Server', 'Checks your Amazon Elastic Compute Cloud (Amazon EC2) instances that are running SQL Server in the past 24 hours. This check alerts you if your instance has less than the minimum number of SQL Server licenses. From the Microsoft SQL Server Licensing Guide, you are paying 4 vCPU licenses even if an instance has only 1 or 2 vCPUs. You can consolidate smaller SQL Server instances to help lower costs.<br/><br/><b>Alert Criteria</b><br/>Yellow: An instance with SQL Server has less than 4 vCPUs.<br/><br/><b>Recommended Action</b><br/>Consider consolidating smaller SQL Server workloads into instances with at least 4 vCPUs.<br/><br/><b>Additional Resources</b><br/><a href="https://aws.amazon.com/sql/" target="blank">Microsoft SQL Server on AWS</a><br/><a href="https://aws.amazon.com/windows/resources/licensing/" target="blank">Microsoft Licensing on AWS</a><br/><a href="https://www.microsoft.com/en-us/sql-server/sql-server-2019-pricing" target="blank">Microsoft SQL Server Licensing Guide</a><br/>')
, ROW ('Qsdfp3A4L3', 'en', 'Amazon EC2 instances with Microsoft SQL Server end of support', 'Checks the SQL Server versions for Amazon Elastic Compute Cloud (Amazon EC2) instances running in the past 24 hours. This check alerts you if the versions are near or have reached the end of support. Each SQL Server version offers 10 years of support, including 5 years of mainstream support and 5 years of extended support. After the end of support, the SQL Server version won’t receive regular security updates. Running applications with unsupported SQL Server versions can bring security or compliance risks.<br/><br/><b>Alert Criteria</b><br/>Red: An EC2 instance has an SQL Server version that reached the end of support.<br/>Yellow: An EC2 instance has an SQL Server version that will reach the end of support in 12 months.<br/><br/><b>Recommended Action</b><br/>To modernize your SQL Server workloads, consider refactoring to AWS Cloud native databases like Amazon Aurora. For more information, see <a href="https://aws.amazon.com/windows/modernization/" target="blank">Modernize Windows Workloads with AWS</a>.<br/>To move to a fully managed database, consider replatforming to Amazon Relational Database Service (Amazon RDS). For more information, see <a href="https://aws.amazon.com/rds/sqlserver/" target="blank">RDS for SQL Server</a>.<br/>To upgrade your SQL Server on EC2, consider using the automation runbook to simplify your upgrade. For more information, see the <a href="https://docs.aws.amazon.com/systems-manager-automation-runbooks/latest/userguide/automation-awsec2-CloneInstanceAndUpgradeSQLServer.html" target="blank">AWS Systems Manager documentation</a>.<br/>If you can’t upgrade your SQL Server on EC2, consider the End-of-Support Migration Program (EMP) for Windows Server. For more information, see the <a href="https://aws.amazon.com/emp-windows-server/" target="blank">EMP Website</a><br/><br/><b>Additional Resources</b><br/><a href="https://aws.amazon.com/sql/sql2008-eos/" target="blank">Get ready for SQL Server end of support with AWS</a><br/><a href="https://aws.amazon.com/sql/" target="blank">Microsoft SQL Server on AWS</a><br/>')
, ROW ('Hs4Ma3G100', 'en', 'Amazon SageMaker notebook instances should not have direct internet access', 'Checks if direct internet access is disabled for an Amazon SageMaker notebook instance by examining the DirectInternetAccess field is disabled for an Amazon SageMaker notebook instance.')
, ROW ('Hs4Ma3G101', 'en', 'Amazon Elastic MapReduce cluster master nodes should not have public IP addresses', 'Checks if master nodes on EMR clusters have public IP addresses.')
, ROW ('Hs4Ma3G102', 'en', 'Connections to Amazon Redshift clusters should be encrypted in transit', 'Checks if connections to Amazon Redshift clusters are required to use encryption in transit. The check fails if the Amazon Redshift cluster parameter require_SSL is not set to 1.')
, ROW ('Hs4Ma3G103', 'en', 'Amazon Redshift clusters should prohibit public access', 'Checks if Amazon Redshift clusters are publicly accessible. It evaluates the publiclyAccessible field in the cluster configuration item.')
, ROW ('Hs4Ma3G104', 'en', 'Redshift clusters should use enhanced VPC routing', 'Checks if a Redshift cluster has EnhancedVpcRouting enabled.')
, ROW ('Hs4Ma3G105', 'en', 'Amazon Redshift should have automatic upgrades to major versions enabled', 'Checks if an Amazon Redshift cluster is configured with automatic upgrades to major versions.')
, ROW ('Hs4Ma3G106', 'en', 'Amazon Redshift clusters should have audit logging enabled', 'Checks if an Amazon Redshift cluster has audit logging enabled.')
, ROW ('Hs4Ma3G107', 'en', 'CloudFront distributions should require encryption in transit', 'Checks if an Amazon CloudFront distribution requires viewers to use HTTPS directly, or if it uses redirection. The check fails if ViewerProtocolPolicy is set to allow-all for defaultCacheBehavior or for cacheBehaviors.')
, ROW ('Hs4Ma3G108', 'en', 'CloudTrail trails should be integrated with Amazon CloudWatch Logs', 'Checks if AWS CloudTrail trails are configured to send logs to Amazon CloudWatch Logs.')
, ROW ('Hs4Ma3G109', 'en', 'CloudTrail log file validation should be enabled', 'Checks if CloudTrail log file validation is enabled.')
, ROW ('Hs4Ma3G110', 'en', 'CloudTrail should have encryption at-rest enabled', 'Checks whether AWS CloudTrail is configured to use the server-side encryption (SSE) AWS Key Management Service (AWS KMS) key encryption. The check will pass if the KmsKeyId is defined.')
, ROW ('Hs4Ma3G111', 'en', 'CloudTrail should be enabled and configured with at least one multi-region trail', 'Checks that there is at least one multi-region AWS CloudTrail trail.')
, ROW ('Hs4Ma3G112', 'en', 'Secrets Manager secrets should be rotated within a specified number of days', 'Checks if your secrets have rotated at least once within 90 days.')
, ROW ('Hs4Ma3G113', 'en', 'Secrets Manager secrets configured with automatic rotation should rotate successfully', 'Checks if an AWS Secrets Manager secret rotated successfully based on the rotation schedule. The check fails if RotationOccurringAsScheduled is false. The check does not evaluate secrets that do not have rotation configured.')
, ROW ('Hs4Ma3G114', 'en', 'Remove unused Secrets Manager secrets', 'Checks if your secrets have been accessed within a specified number of days. The default value is 90 days. Secrets that have not been accessed even once within the number days you define, fail this check.')
, ROW ('Hs4Ma3G115', 'en', 'Secrets Manager secrets should have automatic rotation enabled', 'Checks if a secret stored in AWS Secrets Manager is configured to rotate automatically.')
, ROW ('Hs4Ma3G116', 'en', 'EBS snapshots should not be public, determined by the ability to be restorable by anyone', 'Checks if Amazon Elastic Block Store snapshots are not publicly restorable.')
, ROW ('Hs4Ma3G117', 'en', 'Attached EBS volumes should be encrypted at-rest', 'Checks if the EBS volumes that are in an attached state are encrypted.')
, ROW ('Hs4Ma3G118', 'en', 'The VPC default security group should not allow inbound and outbound traffic', 'Checks that the default security group of a VPC does not allow inbound or outbound traffic.')
, ROW ('Hs4Ma3G119', 'en', 'EBS volumes should be attached to EC2 instances', 'Checks if EBS volumes are attached to EC2 instances.')
, ROW ('Hs4Ma3G120', 'en', 'Stopped EC2 instances should be removed after a specified time period', 'Checks if any EC2 instances have been stopped for more than the allowed number of days. An EC2 instance fails this check if it is stopped for longer than the maximum allowed time period, which by default is 30 days.')
, ROW ('Hs4Ma3G121', 'en', 'EBS default encryption should be enabled', 'Checks if Amazon Elastic Block Store (EBS) encryption is enabled by default. The check fails if EBS default encryption is not enabled.')
, ROW ('Hs4Ma3G122', 'en', 'VPC flow logging should be enabled in all VPCs', 'Checks if Amazon Virtual Private Cloud flow logs are found and enabled for Amazon VPCs. The traffic type is set to Reject.')
, ROW ('Hs4Ma3G123', 'en', 'EC2 instances should not have a public IPv4 address', 'Checks if EC2 instances have a public IP address. The check fails if the publicIp field is present in the EC2 instance configuration item. This check applies to IPv4 addresses only.')
, ROW ('Hs4Ma3G124', 'en', 'EC2 instances should use Instance Metadata Service Version 2 (IMDSv2)', 'Checks if your Amazon Elastic Compute Cloud (Amazon EC2) instance metadata version is configured with Instance Metadata Service Version 2 (IMDSv2). The check passes if HttpTokens is set to required for IMDSv2. The check fails if HttpTokens is set to optional.')
, ROW ('Hs4Ma3G125', 'en', 'API Gateway should be associated with a WAF Web ACL', 'Checks to see if an API Gateway stage is using an AWS WAF Web ACL. This check fails if an AWS WAF Web ACL is not attached to a REST API Gateway stage.')
, ROW ('Hs4Ma3G126', 'en', 'DynamoDB Accelerator (DAX) clusters should be encrypted at rest', 'Checks if a DAX cluster is encrypted at rest.')
, ROW ('Hs4Ma3G127', 'en', 'API Gateway REST and WebSocket API execution logging should be enabled', 'Checks if all stages of Amazon API Gateway REST and WebSocket APIs have logging enabled. The check fails if logging is not enabled for all methods of a stage or if loggingLevel is neither ERROR nor INFO.')
, ROW ('Hs4Ma3G128', 'en', 'API Gateway REST API stages should be configured to use SSL certificates for backend authentication', 'Checks if Amazon API Gateway REST API stages have SSL certificates configured that backend systems can use to authenticate that incoming requests are from the API Gateway.')
, ROW ('Hs4Ma3G129', 'en', 'API Gateway REST API stages should have AWS X-Ray tracing enabled', 'Checks if AWS X-Ray active tracing is enabled for your Amazon API Gateway REST API stages.')
, ROW ('Hs4Ma3G130', 'en', 'Lambda functions should use supported runtimes', 'Checks that the lambda function settings for runtimes, match the expected values set for the supported runtimes for each language. The supported runtimes this check assesses for are: nodejs14.x, nodejs12.x, python3.8, python3.7, python3.6, java11, java8, go1.x, dotnetcore2.1, dotnetcore3.1, ruby2.7.')
, ROW ('Hs4Ma3G131', 'en', 'Lambda function policies should prohibit public access', 'Checks if the AWS Lambda function policy attached to the Lambda resource prohibits public access. If the Lambda function policy allows public access, the check fails.')
, ROW ('Hs4Ma3G132', 'en', 'Database Migration Service replication instances should not be public', 'Checks if AWS Database Migration Service replication instances are public by examining the PubliclyAccessible field value.')
, ROW ('Hs4Ma3G133', 'en', 'IAM customer managed policies should not allow decryption actions on all KMS keys', 'Checks if the default version of IAM customer managed policies allow principals to use the AWS Key Management Service (KMS) decryption actions on all resources. This check fails if kms:Decrypt or kms:ReEncryptFrom actions are allowed on all KMS keys. The check evaluates both attached and unattached customer managed policies. It does not check inline policies or AWS managed policies.')
, ROW ('Hs4Ma3G134', 'en', 'IAM principals should not have IAM inline policies that allow decryption actions on all KMS keys', 'Checks if the inline policies embedded in your IAM principals (Role/User/Group) allow the AWS Key Management Service (KMS) decryption actions on all KMS keys. This check fails if kms:Decrypt or kms:ReEncryptFrom actions are allowed on all KMS keys in an inline policy.')
, ROW ('Hs4Ma3G135', 'en', 'AWS KMS keys should not be deleted unintentionally', 'Checks whether AWS Key Management Service (KMS) keys are scheduled for deletion. The check fails if a KMS key is scheduled for deletion.')
, ROW ('Hs4Ma3G136', 'en', 'Amazon SQS queues should be encrypted at rest', 'Checks if Amazon SQS queues are encrypted at rest.')
, ROW ('Hs4Ma3G137', 'en', 'IAM policies should not allow full "*" administrative privileges', 'Checks if the default version of AWS Identity and Access Management (IAM) policies (also known as customer managed policies) do not have administrator access with a statement that has "Effect": "Allow" with "Action": "*" over "Resource": "*". It only assesses for the Customer Managed Policies that you created, but not inline and AWS Managed Policies.')
, ROW ('Hs4Ma3G138', 'en', 'IAM users should not have IAM policies attached', 'Checks that none of your IAM users have policies attached. Instead, IAM users must inherit permissions from IAM groups or roles.')
, ROW ('Hs4Ma3G139', 'en', 'IAM users access keys should be rotated every 90 days or less', 'Checks if the active access keys are rotated within 90 days.')
, ROW ('Hs4Ma3G140', 'en', 'IAM root user access key should not exist', 'Checks if the root user access key is available.')
, ROW ('Hs4Ma3G141', 'en', 'MFA should be enabled for all IAM users that have a console password', 'Checks if AWS Multi-Factor Authentication (MFA) is enabled for all AWS Identity and Access Management (IAM) users that use a console password.')
, ROW ('Hs4Ma3G142', 'en', 'Hardware MFA should be enabled for the root user', 'Checks if your AWS account is enabled to use hardware multi-factor authentication (MFA) device to sign in with root credentials.')
, ROW ('Hs4Ma3G143', 'en', 'Password policies for IAM users should have strong configurations', 'Checks if the account password policy for IAM users uses the following recommended configurations: RequireUppercaseCharacters: true, RequireLowercaseCharacters: true, RequireSymbols: true, RequireNumbers: true, MinimumPasswordLength: 8.')
, ROW ('Hs4Ma3G144', 'en', 'Unused IAM user credentials should be removed', 'Checks if your IAM users have passwords or active access keys that were not used within the previous 90 days.')
, ROW ('Hs4Ma3G145', 'en', 'Amazon ECS task definitions should have secure networking modes and user definitions.', 'Checks if an Amazon ECS Task Definition with host networking mode has "privileged" or "user" container definitions. The check fails with host network mode and container definitions are privileged=false or empty and user=root or empty.')
, ROW ('Hs4Ma3G146', 'en', 'ECS services should not have public IP addresses assigned to them automatically', 'Checks if ECS services are configured to automatically assign public IP addresses. This check fails if AssignPublicIP is ENABLED.')
, ROW ('Hs4Ma3G147', 'en', 'Amazon Elasticsearch Service domains should be in a VPC', 'Checks whether Amazon Elasticsearch Service domains are in a VPC. It does not evaluate the VPC subnet routing configuration to determine public reachability. This check also does not check whether the Amazon OpenSearch Service resource-based policy permits public access by other accounts or external entities. You should ensure that Amazon Elasticsearch Service domains are not attached to public subnets. See Resource-based policies (https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ac.html#ac-types-resource) in the Amazon OpenSearch Service (successor to Amazon Elasticsearch Service) Developer Guide. You should also ensure that your VPC is configured according to the recommended best practices. See Security best practices for your VPC (https://docs.aws.amazon.com/vpc/latest/userguide/vpc-security-best-practices.html) in the Amazon VPC User Guide.')
, ROW ('Hs4Ma3G148', 'en', 'Elastic Beanstalk environments should have enhanced health reporting enabled', 'Checks if enhanced health reporting is enabled for your AWS Elastic Beanstalk environments.')
, ROW ('Hs4Ma3G149', 'en', 'Elastic Beanstalk managed platform updates should be enabled', 'Checks if managed platform updates are enabled for the AWS Elastic Beanstalk environment.')
, ROW ('Hs4Ma3G150', 'en', 'Elasticsearch domains should encrypt data sent between nodes', 'Checks if Elasticsearch domains have node-to-node encryption enabled.')
, ROW ('Hs4Ma3G151', 'en', 'An RDS event notifications subscription should be configured for critical database parameter group events', 'Checks if an Amazon RDS Event subscription for RDS parameter groups is configured to notify on event category of "configuration change".')
, ROW ('Hs4Ma3G152', 'en', 'An RDS event notifications subscription should be configured for critical database instance events', 'Checks if an Amazon RDS Event subscription for RDS instances is configured to notify on event categories of both "maintenance", "configuration change", and "failure".')
, ROW ('Hs4Ma3G153', 'en', 'RDS instances should not use a database engine default port', 'Checks if RDS instances use the default port of that database engine.')
, ROW ('Hs4Ma3G154', 'en', 'An RDS event notifications subscription should be configured for critical database security group events', 'Checks if an Amazon RDS Event subscription for RDS security groups is configured to notify on event categories of both "configuration change" and "failure".')
, ROW ('Hs4Ma3G155', 'en', 'EC2 instances should be managed by AWS Systems Manager', 'Checks if the Amazon EC2 instances in your account are managed by AWS Systems Manager.')
, ROW ('Hs4Ma3G156', 'en', 'EC2 instances managed by Systems Manager should have a patch compliance status of COMPLIANT after a patch installation', 'Checks if the compliance status of the Amazon EC2 Systems Manager patch compliance is COMPLIANT or NON_COMPLIANT after the patch installation on the instance. It only assesses instances that are managed by AWS Systems Manager Patch Manager.')
, ROW ('Hs4Ma3G157', 'en', 'EC2 instances managed by Systems Manager should have an association compliance status of COMPLIANT', 'Checks if the status of the AWS Systems Manager association compliance is COMPLIANT or NON_COMPLIANT after the association is executed on an instance.')
, ROW ('Hs4Ma3G158', 'en', 'SSM documents should not be public', 'Checks if AWS Systems Manager documents that the account owns are public. This check fails if SSM documents that have "Self" as the owner are public.')
, ROW ('Hs4Ma3G159', 'en', 'Elastic File System should be configured to encrypt file data at-rest using AWS KMS', 'Checks if Amazon Elastic File System (Amazon EFS) is configured to encrypt the file data using AWS Key Management Service (AWS KMS). The check will fail if the encrypted key is set to false on DescribeFileSystems or if the KmsKeyId key on DescribeFileSystems does not match the KmsKeyId parameter.')
, ROW ('Hs4Ma3G160', 'en', 'IAM authentication should be configured for RDS instances', 'Checks if an RDS DB instance has IAM database authentication enabled.')
, ROW ('Hs4Ma3G161', 'en', 'IAM authentication should be configured for RDS clusters', 'Checks if an RDS DB cluster has IAM database authentication enabled.')
, ROW ('Hs4Ma3G162', 'en', 'RDS automatic minor version upgrades should be enabled', 'Checks if automatic minor version upgrades are enabled for the Amazon RDS database instance.')
, ROW ('Hs4Ma3G163', 'en', 'RDS DB clusters should be configured to copy tags to snapshots', 'Checks if RDS DB clusters are configured to copy all tags to snapshots when the snapshots are created.')
, ROW ('Hs4Ma3G164', 'en', 'RDS DB instances should be configured to copy tags to snapshots', 'Checks if RDS DB instances are configured to copy all tags to snapshots when the snapshots are created.')
, ROW ('Hs4Ma3G165', 'en', 'RDS instances should be deployed in a VPC', 'Checks if an RDS instance is deployed in a VPC (EC2-VPC).')
, ROW ('Hs4Ma3G166', 'en', 'An RDS event notifications subscription should be configured for critical cluster events', 'Checks if an Amazon RDS Event subscription for RDS clusters is configured to notify on event categories of both "maintenance" and "failure".')
, ROW ('Hs4Ma3G167', 'en', 'S3 buckets should have server-side encryption enabled', 'Checks that your Amazon S3 bucket either has Amazon S3 default encryption enabled or that the S3 bucket policy explicitly denies put-object requests without server side encryption.')
, ROW ('Hs4Ma3G168', 'en', 'S3 buckets should require requests to use Secure Socket Layer', 'Checks if S3 buckets have policies that require requests to use Secure Socket Layer (SSL).')
, ROW ('Hs4Ma3G169', 'en', 'S3 permissions granted to other AWS accounts in bucket policies should be restricted', 'Checks if the S3 bucket policy allows sensitive bucket-level or object-level actions from a principal in another AWS account. The check fails if any of the following actions are allowed in the S3 bucket policy for a principal in another AWS account: s3:DeleteBucketPolicy, s3:PutBucketAcl, s3:PutBucketPolicy, s3:PutObjectAcl, and s3:PutEncryptionConfiguration.')
, ROW ('Hs4Ma3G170', 'en', 'S3 Block Public Access setting should be enabled', 'Checks if the following public access block settings are configured from account level: ignorePublicAcls: True, blockPublicPolicy: True, blockPublicAcls: True, restrictPublicBuckets: True.')
, ROW ('Hs4Ma3G171', 'en', 'S3 buckets should prohibit public read access', 'Checks if your S3 buckets allow public read access by evaluating the Block Public Access settings, the bucket policy, and the bucket access check list (ACL).')
, ROW ('Hs4Ma3G172', 'en', 'S3 buckets should prohibit public write access', 'Checks if your S3 buckets allow public write access by evaluating the Block Public Access settings, the bucket policy, and the bucket access check list (ACL).')
, ROW ('Hs4Ma3G173', 'en', 'S3 Block Public Access setting should be enabled at the bucket-level', 'Checks if Amazon S3 buckets have bucket level public access blocks applied. This check fails if any of the bucket level settings are set to "false" public: ignorePublicAcls, blockPublicPolicy, blockPublicAcls, restrictPublicBuckets.')
, ROW ('Hs4Ma3G174', 'en', 'CodeBuild GitHub or Bitbucket source repository URLs should use OAuth', 'Checks if the GitHub or Bitbucket source repository URL contains either personal access tokens or user name and password.')
, ROW ('Hs4Ma3G175', 'en', 'CodeBuild project environment variables should not contain clear text credentials', 'Checks if the project contains environment variables AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY.')
, ROW ('Hs4Ma3G176', 'en', 'ACM certificates should be renewed after a specified time period', 'Checks if ACM Certificates in your account are marked for expiration within a specified time period. Certificates provided by ACM are automatically renewed. ACM does not automatically renew certificates that you import.')
, ROW ('Hs4Ma3G177', 'en', 'Auto scaling groups associated with a load balancer should use load balancer health checks', 'Checks if your Auto Scaling groups that are associated with a load balancer are using Elastic Load Balancing health checks.')
, ROW ('Hs4Ma3G178', 'en', 'Security groups should only allow unrestricted incoming traffic for authorized ports', 'Checks if the security groups allow unrestricted incoming traffic. The check fails if ports allow unrestricted traffic on ports other than 80 and 443, which are default values for parameter authorizedTcpPorts.')
, ROW ('Hs4Ma3G179', 'en', 'SNS topics should be encrypted at-rest using AWS KMS', 'Checks if an Amazon SNS topic is encrypted at rest using AWS KMS.')
, ROW ('Hs4Ma3G180', 'en', 'Amazon Elasticsearch Service domain error logging to CloudWatch Logs should be enabled', 'Checks whether Amazon Elasticsearch Service domains are configured to send error logs to CloudWatch Logs.')
, ROW ('Hs4Ma3G181', 'en', 'Classic Load Balancers with SSL/HTTPS listeners should use a certificate provided by AWS Certificate Manager', 'Checks if a Classic Load Balancer uses HTTPS/SSL certificates provided by AWS Certificate Manager. The check fails if a Classic Load Balancer that is configured with an HTTPS/SSL listener does not use a certificate provided by AWS Certificate Manager.')
, ROW ('Hs4Ma3G182', 'en', 'Classic Load Balancer listeners should be configured with HTTPS or TLS termination', 'Checks if your Classic Load Balancer listeners are configured with HTTPS or TLS protocol for front-end (client to load balancer) connections. The check is applicable if a Classic Load Balancer has listeners. If your Classic Load Balancer does not have a listener configured, then the check does not report any findings.')
, ROW ('Hs4Ma3G183', 'en', 'Application load balancer should be configured to drop http headers', 'This check evaluates AWS Application Load Balancers (ALB) to ensure they are configured to drop http headers. By default, ALBs are not configured to drop invalid http header values. This check evaluates all ALBs fails if the attribute value of routing.http.drop_invalid_header_fields.enabled is set to false.')
, ROW ('Hs4Ma3G184', 'en', 'Application and Classic Load Balancers logging should be enabled', 'Checks if the Application Load Balancer and the Classic Load Balancer have logging enabled. The check fails if the access_logs.s3.enabled is false.')
, ROW ('Hs4Ma3G185', 'en', 'IAM customer managed policies that you create should not allow wildcard actions for services', 'Checks if the IAM identity-based custom policies have Allow statements that grant permissions for all actions on a service. The check fails if any policy statement includes "Effect": "Allow" with "Action": "Service:".')
, ROW ('Hs4Ma3G186', 'en', 'AWS WAF Classic Global Web ACL logging should be enabled', 'Checks if logging is enabled for a WAF global Web ACL. This check fails if logging is not enabled for the Web ACL.')
, ROW ('Hs4Ma3G187', 'en', 'Connections to Amazon Elasticsearch Service domains should be encrypted using TLS 1.2', 'Checks whether connections to Amazon Elasticsearch Service domains are required to use TLS 1.2.  The check fails if the Amazon Elasticsearch Service domain TLSSecurityPolicy is not Policy-Min-TLS-1-2-2019-07.')
, ROW ('Hs4Ma3G188', 'en', 'GuardDuty should be enabled', 'Checks if Amazon GuardDuty is enabled in your AWS account and region.')
, ROW ('Hs4Ma3G189', 'en', 'Enhanced monitoring should be configured for RDS DB instances', 'Checks if enhanced monitoring is enabled for your RDS DB instances.')
, ROW ('Hs4Ma3G190', 'en', 'RDS clusters should have deletion protection enabled', 'Checks if RDS clusters have deletion protection enabled.')
, ROW ('Hs4Ma3G191', 'en', 'RDS cluster snapshots and database snapshots should be encrypted at rest', 'Checks if Amazon RDS cluster snapshots and database snapshots are encrypted.')
, ROW ('Hs4Ma3G192', 'en', 'RDS DB Instances should prohibit public access, determined by the PubliclyAccessible configuration', 'Checks if RDS instances are publicly accessible by evaluating the publiclyAccessible field in the instance configuration item.')
, ROW ('Hs4Ma3G193', 'en', 'RDS DB instances should have encryption at-rest enabled', 'Checks if storage encryption is enabled for your RDS DB instances.')
, ROW ('Hs4Ma3G194', 'en', 'RDS snapshot should be private', 'Checks if Amazon Relational Database Service (Amazon RDS) snapshots are public.')
, ROW ('Hs4Ma3G195', 'en', 'CloudFront distributions should have origin access identity enabled', 'Checks if an Amazon CloudFront distribution with an Amazon S3 origin type has Origin Access Identity (OAI) configured. The check fails if the CloudFront distribution that is backed by Amazon S3 does not have OAI configured.')
, ROW ('Hs4Ma3G196', 'en', 'AWS Config should be enabled', 'Checks if the Config service is enabled in the account for the local region and is recording all resources.')
, ROW ('Hs4Ma3G197', 'en', 'Amazon Elasticsearch Service domains should have encryption at-rest enabled', 'Checks whether Amazon Elasticsearch Service domains have encryption at rest configuration enabled. This check fails if the EncryptionAtRestOptions field is not enabled.')
, ROW ('Hs4Ma3G198', 'en', 'RDS DB instances should have deletion protection enabled', 'Checks if RDS DB instances have deletion protection enabled.')
, ROW ('Hs4Ma3G199', 'en', 'Database logging should be enabled', 'Checks if the following Amazon RDS logs are enabled and sent to CloudWatch Logs: Oracle: (Alert, Audit, Trace, Listener), PostgreSQL: (Postgresql, Upgrade), MySQL: (Audit, Error, General, SlowQuery), MariaDB: (Audit, Error, General, SlowQuery), SQL Server: (Error, Agent), Aurora: (Audit, Error, General, SlowQuery), Aurora-MySQL: (Audit, Error, General, SlowQuery), Aurora-PostgreSQL: (Postgresql).')
, ROW ('Hs4Ma3G200', 'en', 'CloudFront distributions should have a default root object configured', 'Checks if an Amazon CloudFront distribution is configured to return a specific object that is the default root object. The check fails if the CloudFront distribution does not have a default root object configured.')
, ROW ('Hs4Ma3G201', 'en', 'CloudFront distributions should have WAF enabled', 'Checks to see if Amazon CloudFront distributions are associated with either WAF or WAFv2 web ACLs. The check fails if a CloudFront distribution is not associated with a web ACL.')
, ROW ('Hs4Ma3G202', 'en', 'API Gateway REST API cache data should be encrypted at rest', 'Checks if all methods in Amazon API Gateway REST API stages that have cache enabled are encrypted. The check fails if any method in API Gateway REST API stage is configured to cache and the cache is not encrypted.')
, ROW ('Hs4Ma3G203', 'en', 'Amazon Elasticsearch Service domains should have audit logging enabled', 'This check checks whether Amazon Elasticsearch Service domains have audit logging enabled. This check fails if an Amazon Elasticsearch Service domain does not have audit logging enabled.')
, ROW ('Hs4Ma3G204', 'en', 'Security groups should not allow unrestricted access to ports with high risk', 'Checks if unrestricted incoming traffic for the security groups is accessible to the specified ports [3389, 20, 23, 110, 143, 3306, 8080, 1433, 9200, 9300, 25, 445, 135, 21, 1434, 4333, 5432, 5500, 5601, 22 ] that have the highest risk. This check passes when none of the rules in a security group allow ingress traffic from 0.0.0.0/0 for the listed ports.')
, ROW ('Hs4Ma3G205', 'en', 'Classic Load Balancers with HTTPS/SSL listeners should use a predefined security policy that has strong configuration', 'Checks if your Classic Load Balancer SSL listeners use the predefined policy ELBSecurityPolicy-TLS-1-2-2017-01. The check fails if the Classic Load Balancer SSL listeners do not use the predefined policy ELBSecurityPolicy-TLS-1-2-2017-01.')
, ROW ('Hs4Ma3G206', 'en', 'Amazon EC2 should be configured to use VPC endpoints that are created for the Amazon EC2 service', 'Checks if a service endpoint for Amazon EC2 is created for each VPC. The check fails if a VPC does not have a VPC endpoint created for the Amazon EC2 service.')
, ROW ('Hs4Ma3G207', 'en', 'EC2 subnets should not automatically assign public IP addresses', 'Checks if the assignment of public IPs in Amazon Virtual Private Cloud (VPC) subnets have the MapPublicIpOnLaunch set to FALSE. The check will pass if the flag is set to FALSE.')
, ROW ('Hs4Ma3G208', 'en', 'EC2 instances should not use multiple ENIs', 'Checks to see if Amazon EC2 instance uses multiple ENI/EFA. This check will pass if single network adapters is used.')
, ROW ('Hs4Ma3G209', 'en', 'Unused Network Access Control Lists should be removed', 'Checks to see if there are any NACLs (Network Access Control List) that are unused. The check will check the item configuration of the resource AWS::EC2::NetworkAcl and determine the relationships of the NACL.')
, ROW ('Hs4Ma3G210', 'en', 'CloudFront distributions should have logging enabled', 'Checks to see if server access logging is enabled on Amazon CloudFront Distributions. The check will fail if access logging is not enabled for the distribution.')
, ROW ('COr6dfpM03', 'en', 'Amazon EBS over-provisioned volumes', 'Checks the Amazon Elastic Block Storage (Amazon EBS) volumes that were running at any time during the lookback period. This check alerts you if any EBS volumes were over-provisioned for your workloads. When you have over-provisioned volumes, you’re paying for unused resources. Although some scenarios can result in low optimization by design, you can often lower your costs by changing the configuration of your EBS volumes. Estimated monthly savings are calculated by using the current usage rate for EBS volumes. Actual savings will vary if the volume isn’t present for a full month.<br/><br/><b>Source</b><br/>AWS Compute Optimizer<br/><br/><b>Alert Criteria</b><br/>Yellow: An EBS Volume that was over-provisioned during the lookback period. To determine if a volume is over-provisioned, we consider all default CloudWatch metrics (including IOPS and throughput). The algorithm used to identify over-provisioned EBS volumes follows AWS best practices. The algorithm is updated when a new pattern has been identified.<br/><br/><b>Recommended Action</b><br/>Consider downsizing volumes that have low utilization.<br/><br/><b>Additional Resources</b><br/>For more information about this recommendation, see the <a href="https://docs.aws.amazon.com/console/awssupport/trusted-advisor/compute-optimizer" target="blank">Trusted Advisor documentation.</a>.')
, ROW ('COr6dfpM04', 'en', 'Amazon EBS under-provisioned volumes', 'Checks the Amazon Elastic Block Storage (Amazon EBS) volumes that were running at any time during the lookback period. This check alerts you if any EBS volumes were under-provisioned for your workloads. Consistent high utilization can indicate optimized, steady performance, but can also indicate that an application does not have enough resources.<br/><br/><b>Source</b><br/>AWS Compute Optimizer<br/><br/><b>Alert Criteria</b><br/>Yellow: An EBS Volume that was under-provisioned during the lookback period. To determine if a volume is under-provisioned, we consider all default CloudWatch metrics (including IOPS and throughput). The algorithm used to identify under-provisioned EBS volumes follows AWS best practices. The algorithm is updated when a new pattern has been identified.<br/><br/><b>Recommended Action</b><br/>Consider upsizing volumes that have high utilization.<br/><br/><b>Additional Resources</b><br/>For more information about this recommendation, see the <a href="https://docs.aws.amazon.com/console/awssupport/trusted-advisor/compute-optimizer" target="blank">Trusted Advisor documentation</a>.')
, ROW ('COr6dfpM05', 'en', 'AWS Lambda over-provisioned functions for memory size', 'Checks the AWS Lambda functions that were invoked at least once during the lookback period. This check alerts you if any of your Lambda functions were over-provisioned for memory size. When you have Lambda functions that are over-provisioned for memory sizes, you’re paying for unused resources. Although some scenarios can result in low utilization by design, you can often lower your costs by changing the memory configuration of your Lambda functions. Estimated monthly savings are calculated by using the current usage rate for Lambda functions.<br/><br/><b>Source</b><br/>AWS Compute Optimizer<br/><br/><b>Alert Criteria</b><br/>Yellow: A Lambda function that was over-provisioned for memory size during the lookback period. To determine if a Lambda function is over-provisioned, we consider all default CloudWatch metrics for that function. The algorithm used to identify over-provisioned Lambda functions for memory size follows AWS best practices. The algorithm is updated when a new pattern has been identified.<br/><br/><b>Recommended Action</b><br/>Consider reducing the memory size of your Lambda functions.<br/><br/><b>Additional Resources</b><br/>For more information about this recommendation, see the <a href="https://docs.aws.amazon.com/console/awssupport/trusted-advisor/compute-optimizer" target="blank">Trusted Advisor documentation page</a>.')
, ROW ('COr6dfpM06', 'en', 'AWS Lambda under-provisioned functions for memory size', 'Checks the AWS Lambda functions that were invoked at least once during the lookback period. This check alerts you if any of your Lambda functions were under-provisioned for memory size. When you have Lambda functions that are under-provisioned for memory size, these functions take longer time to complete.<br/><br/><b>Source</b><br/>AWS Compute Optimizer<br/><br/><b>Alert Criteria</b><br/>Yellow: A Lambda function that was under-provisioned for memory size during the lookback period. To determine if a Lambda function is under-provisioned, we consider all default CloudWatch metrics for that function. The algorithm used to identify under-provisioned Lambda functions for memory size follows AWS best practices. The algorithm is updated when a new pattern has been identified.<br/><br/><b>Recommended Action</b><br/>Consider increasing the memory size of your Lambda functions.<br/><br/><b>Additional Resources</b><br/>For more information about this recommendation, see the <a href="https://docs.aws.amazon.com/console/awssupport/trusted-advisor/compute-optimizer" target="blank">Trusted Advisor documentation</a>.')
, ROW ('Hs4Ma3G211', 'en', 'S3 buckets with versioning enabled should have lifecycle policies configured', 'Checks if Amazon Simple Storage Service (Amazon S3) version enabled buckets have lifecycle policy configured. This rule fails if Amazon S3 lifecycle policy is not enabled.')
, ROW ('Hs4Ma3G212', 'en', 'S3 buckets should have event notifications enabled', 'Checks if S3 Event Notifications are enabled on an S3 bucket. This check fails if S3 Event Notifications are not enabled on a bucket.')
, ROW ('Hs4Ma3G213', 'en', 'S3 access control lists (ACLs) should not be used to manage user access to buckets', 'Checks if S3 buckets allow user permissions via access check lists (ACLs). This check fails if ACLs are configured for user access on S3 Bucket.')
, ROW ('Hs4Ma3G214', 'en', 'Network ACLs should not allow ingress from 0.0.0.0/0 to port 22 or port 3389', 'Checks if a network access check list (NACL) allows unrestricted access to the default ports for SSH/RDP ingress traffic. The rule fails if a NACL inbound entry allows a source CIDR block of 0.0.0.0/0 or ::/0 for ports 22 or 3389')
, ROW ('Hs4Ma3G215', 'en', 'Unused EC2 security groups should be removed', 'Checks that security groups are attached to Amazon EC2 instances or to an elastic network interface. The check will fail the security group is not associated with an Amazon EC2 instance or an elastic network interface.')
, ROW ('Hs4Ma3G216', 'en', 'ECR repositories should have at least one lifecycle policy configured', 'Checks if an ECR repository has at least one lifecycle policy configured. This check fails if an ECR repository does not have any lifecycle policies configured.')
, ROW ('Hs4Ma3G217', 'en', 'CodeBuild project environments should have a logging configuration', 'Checks if a CodeBuild project environment has at least one log option enabled.')
, ROW ('Hs4Ma3G218', 'en', 'CodeBuild project environments should not have privileged mode enabled', 'Checks if an AWS CodeBuild project environment has privileged mode enabled.')
, ROW ('Hs4Ma3G219', 'en', 'Amazon Redshift clusters should not use the default Admin username', 'Checks if a Redshift cluster has changed the Admin username from its default value. This check will fail if the admin username for a Redshift cluster is set to awsuser.')
, ROW ('Hs4Ma3G220', 'en', 'Connections to OpenSearch domains should be encrypted using TLS 1.2', 'Checks if connections to OpenSearch domains are required to use TLS 1.2. The check fails if the OpenSearch domain TLSSecurityPolicy is not Policy-Min-TLS-1-2-2019-07.')
, ROW ('Hs4Ma3G221', 'en', 'OpenSearch domains should have audit logging enabled', 'Checks if Amazon OpenSearch Service domains have audit logging enabled.')
, ROW ('Hs4Ma3G222', 'en', 'OpenSearch domain error logging to CloudWatch Logs should be enabled', 'Checks if Amazon OpenSearch domains are configured to send error logs to CloudWatch Logs. This check fails if error logging to CloudWatch is not enabled for a domain.')
, ROW ('Hs4Ma3G223', 'en', 'OpenSearch domains should encrypt data sent between nodes', 'Checks if Amazon OpenSearch domains have node-to-node encryption enabled. This check fails if node-to-node encryption is disabled on the domain.')
, ROW ('Hs4Ma3G224', 'en', 'OpenSearch domains should be in a VPC', 'Checks Amazon OpenSearch Service domains are in an Amazon Virtual Private Cloud (VPC).')
, ROW ('Hs4Ma3G225', 'en', 'OpenSearch domains should have encryption at rest enabled', 'Checks if Amazon OpenSearch domains have encryption-at-rest configuration enabled. The check fails if encryption at rest is not enabled.')
, ROW ('Hs4Ma3G226', 'en', 'Amazon EC2 instances launched using Auto Scaling group launch configurations should not have Public IP addresses', 'Checks if Amazon EC2 Auto Scaling groups have public IP addresses enabled using launch configurations.')
, ROW ('Hs4Ma3G227', 'en', 'CloudFront distributions should use custom SSL/TLS certificates', 'Checks if CloudFront distributions are using the default SSL/TLS certificate CloudFront provides instead of a custom one. This check fails for a CloudFront distribution if it uses the default SSL/TLS certificate.')
, ROW ('Hs4Ma3G228', 'en', 'CloudFront distributions should use SNI to serve HTTPS requests', 'Checks if Amazon CloudFront distributions are using a custom SSL/TLS certificate and are configured to use SNI to serve HTTPS requests as opposed to dedicated IP address.')
, ROW ('Hs4Ma3G229', 'en', 'CloudFront distributions should encrypt traffic to custom origins', 'Checks if CloudFront distributions are encrypting traffic to custom origins. This check fails for a CloudFront distribution whose origin protocol policy allows http-only or if it is match-viewer and the viewer protocol policy is allow-all. ')
, ROW ('Hs4Ma3G230', 'en', 'S3 bucket server access logging should be enabled', 'Checks if an Amazon S3 Bucket has server access logging enabled to a chosen target bucket.')
, ROW ('Hs4Ma3G231', 'en', 'Stateless network firewall rule group should not be empty', 'Checks if a Stateless Network Firewall Rule Group contains rules. The rule will fail if there are no rules in a Stateless Network Firewall Rule Group.')
, ROW ('Hs4Ma3G232', 'en', 'RDS Database Clusters should use a custom administrator username', 'Checks if an RDS database cluster has changed the admin username from its default value. This rule will fail if the admin username is set to the default value.')
, ROW ('Hs4Ma3G233', 'en', 'RDS database instances should use a custom administrator username', 'Checks if an Amazon Relational Database Service (Amazon RDS) database instance has changed the admin username from its default value. This rule will only run on RDS database instances. The rule will fail if the admin username is set to the default value.')
)  ignored_tabe_name (check_id, language, name, description)
